@@ -190,7 +190,7 @@ void CustomProjectPart::contextMenu(QPopupMenu *popup, const Context *context)
     KURL url = fcontext->urls().first();
     if (URLUtil::isDirectory(url)) {
         // remember the name of the directory
-        m_contextDirName = url.fileName();
+        m_contextDirName = url.path();
         m_contextDirName = m_contextDirName.mid ( project()->projectDirectory().length() + 1 );
         popup->insertSeparator();
         int id = popup->insertItem( i18n("Make Active Directory"),
@@ -302,7 +302,14 @@ void CustomProjectPart::openProject(const QString &dirName, const QString &proje
     if (m_filelistDir.isEmpty())
        m_filelistDir=dirName;
 
-    QFile f(m_filelistDir + "/" + projectName + ".filelist");
+    if( QFileInfo(m_filelistDir + "/" + projectName.lower() +
+			    ".kdevelop.filelist").exists() )
+    {
+        QDir( m_filelistDir ).rename(
+			projectName.lower()+".kdevelop.filelist",
+			projectName+".kdevelop.filelist");
+    }
+    QFile f( m_filelistDir + "/" + projectName + ".kdevelop.filelist" );
     if (f.open(IO_ReadOnly)) {
         QTextStream stream(&f);
         while (!stream.atEnd()) {
@@ -373,7 +380,8 @@ void CustomProjectPart::populateProject()
                         || (fileName.endsWith(".cpp"))
                         || (fileName.endsWith(".c++"))
                         || (fileName.endsWith(".cxx"))
-                        || (fileName.startsWith("Makefile"))))  //Makefile, Makefile.am, Makefile.in
+                        || (fileName.startsWith("Makefile"))
+			|| (fileName == "CMakeLists.txt")))  //Makefile, Makefile.am, Makefile.in
                 {
                     kdDebug(9025) << "Adding: " << path << endl;
                     m_sourceFiles.append(path.mid(prefixlen));
@@ -393,7 +401,7 @@ void CustomProjectPart::closeProject()
 
 void CustomProjectPart::saveProject()
 {
-    QFile f(m_filelistDir + "/" + m_projectName + ".filelist");
+    QFile f(m_filelistDir + "/" + m_projectName.lower() + ".kdevelop.filelist");
     if (!f.open(IO_WriteOnly))
         return;
 
@@ -437,7 +445,10 @@ DomUtil::PairList CustomProjectPart::runEnvironmentVars() const
   */
 QString CustomProjectPart::runDirectory() const
 {
-    return defaultRunDirectory("kdevcustomproject");
+	QString cwd = defaultRunDirectory("kdevcustomproject");
+    if (cwd.isEmpty())
+      cwd = buildDirectory();
+    return cwd;
 }
 
 
@@ -450,29 +461,35 @@ QString CustomProjectPart::runDirectory() const
   *   if run/directoryradio == custom or relative == false
   *        The absolute path to executable
   */
-QString CustomProjectPart::mainProgram(bool relative) const
+QString CustomProjectPart::mainProgram() const
 {
-    QDomDocument &dom = *projectDom();
+    QDomDocument * dom = projectDom();
 
-    QString directoryRadioString = DomUtil::readEntry(dom, "/kdevcustomproject/run/directoryradio");
-    QString DomMainProgram = DomUtil::readEntry(dom, "/kdevcustomproject/run/mainprogram");
+    if ( !dom ) return QString();
 
-    if ( directoryRadioString == "custom" )
-        return DomMainProgram;
+    QString DomMainProgram = DomUtil::readEntry( *dom, "/kdevcustomproject/run/mainprogram");
 
-    if ( relative == false )
-        return buildDirectory() + "/" + DomMainProgram;
+    if ( DomMainProgram.isEmpty() ) return QString();
 
-    if ( directoryRadioString == "executable" ) {
-        int pos = DomMainProgram.findRev('/');
-        if (pos != -1)
-            return DomMainProgram.mid(pos+1);
+    if ( DomMainProgram.startsWith("/") )   // assume absolute path
+    {
         return DomMainProgram;
     }
-    else
-        return DomMainProgram;
+    else // assume project relative path
+    {
+        return projectDirectory() + "/" + DomMainProgram;
+    }
+
+    return QString();
 }
 
+/** Retuns a QString with the debug command line arguments */
+QString CustomProjectPart::debugArguments() const
+{
+    return DomUtil::readEntry(*projectDom(), "/kdevcustomproject/run/globaldebugarguments");
+}
+
+
 /** Retuns a QString with the run command line arguments */
 QString CustomProjectPart::runArguments() const
 {
@@ -481,8 +498,16 @@ QString CustomProjectPart::runArguments() const
 
 QString CustomProjectPart::activeDirectory() const
 {
-    QDomDocument &dom = *projectDom();
-    return DomUtil::readEntry(dom, "/kdevcustomproject/general/activedir");
+	QDomDocument &dom = *projectDom();
+	KParts::ReadOnlyPart* p = dynamic_cast<KParts::ReadOnlyPart*>(partController()->activePart());
+	if( p )
+    {
+		QString relpath = URLUtil::relativePath( projectDirectory(), p->url().directory() );
+		if( relpath.startsWith("/") )
+			relpath = relpath.right( relpath.length()-1 );
+		return relpath;
+	}
+	return DomUtil::readEntry(dom, "/kdevcustomproject/general/activedir", ".");
 }
 
 
@@ -518,10 +543,17 @@ void CustomProjectPart::addFile(const QString &fileName)
 void CustomProjectPart::addFiles ( const QStringList& fileList )
 {
 	QStringList::ConstIterator it;
-
 	for ( it = fileList.begin(); it != fileList.end(); ++it )
-   {
-      m_sourceFiles.append (*it);
+	{
+		kdDebug(9025) << "Add file: " << *it << endl;
+		if( QDir::isRelativePath( *it ) )
+		{
+			m_sourceFiles.append (*it);
+		}
+		else
+		{
+			m_sourceFiles.append ( URLUtil::getRelativePath(projectDirectory(), *it ) );
+		}
 	}
 
 	saveProject();
@@ -737,22 +769,19 @@ void CustomProjectPart::slotExecute()
         environstr += " ";
     }
 
-    if (mainProgram(true).isEmpty())
+    if (mainProgram().isEmpty())
     // Do not execute non executable targets
         return;
 
     QString program = environstr;
-    // Adds the ./ that is necessary to execute the program in bash shells
-    if (!mainProgram(true).startsWith("/"))
-        program += "./";
-    program += mainProgram(true);
+    program += mainProgram();
     program += " " + runArguments();
 
     bool inTerminal = DomUtil::readBoolEntry(*projectDom(), "/kdevcustomproject/run/terminal");
 
     kdDebug(9025) << "runDirectory: <" << runDirectory() << ">" <<endl;
     kdDebug(9025) << "environstr  : <" << environstr << ">" <<endl;
-    kdDebug(9025) << "mainProgram : <" << mainProgram(true) << ">" <<endl;
+    kdDebug(9025) << "mainProgram : <" << mainProgram() << ">" <<endl;
     kdDebug(9025) << "runArguments: <" << runArguments() << ">" <<endl;
 
     appFrontend()->startAppCommand(runDirectory(), program, inTerminal);
