@@ -171,7 +171,7 @@ void PascalProjectPart::openProject(const QString &dirName, const QString &proje
             }
         }
     } while (!s.isEmpty());
-    
+
     KDevProject::openProject( dirName, projectName );
 }
 
@@ -197,7 +197,10 @@ DomUtil::PairList PascalProjectPart::runEnvironmentVars() const
   */
 QString PascalProjectPart::runDirectory() const
 {
-    return defaultRunDirectory("kdevpascalproject");
+    QString cwd = defaultRunDirectory("kdevpascalproject");
+    if (cwd.isEmpty())
+      cwd = buildDirectory();
+    return cwd;
 }
 
 
@@ -210,36 +213,32 @@ QString PascalProjectPart::runDirectory() const
   *   if run/directoryradio == custom or relative == false
   *        The absolute path to executable
   */
-QString PascalProjectPart::mainProgram(bool relative) const
+QString PascalProjectPart::mainProgram() const
 {
-    QDomDocument &dom = *projectDom();
-    QString configMainProg = DomUtil::readEntry(dom, "/kdevpascalproject/run/mainprogram", "");
-    if (configMainProg.isEmpty())
+    QDomDocument * dom = projectDom();
+
+    if ( !dom ) return QString();
+
+    QString DomMainProgram = DomUtil::readEntry( *dom, "/kdevpascalproject/run/mainprogram");
+
+    if ( DomMainProgram.isEmpty() ) return QString();
+
+    if ( DomMainProgram.startsWith("/") )   // assume absolute path
     {
-        QFileInfo fi(mainSource());
-        return buildDirectory() + "/" + fi.baseName();
-    }
-    else
-        return QDir::cleanDirPath(projectDirectory() + "/" + configMainProg);
-
-    /// \FIXME put the code below into use!
-    QString directoryRadioString = DomUtil::readEntry(dom, "/kdevpascalproject/run/directoryradio");
-    QString DomMainProgram = DomUtil::readEntry(dom, "/kdevpascalproject/run/mainprogram");
-
-    if ( directoryRadioString == "custom" )
-        return DomMainProgram;
-
-    if ( relative == false )
-        return buildDirectory() + "/" + DomMainProgram;
-
-    if ( directoryRadioString == "executable" ) {
-        int pos = DomMainProgram.findRev('/');
-        if (pos != -1)
-            return DomMainProgram.mid(pos+1);
         return DomMainProgram;
     }
-    else
-        return DomMainProgram;
+    else // assume project relative path
+    {
+        return projectDirectory() + "/" + DomMainProgram;
+    }
+
+    return QString();
+}
+
+/** Retuns a QString with the debug command line arguments */
+QString PascalProjectPart::debugArguments() const
+{
+    return DomUtil::readEntry(*projectDom(), "/kdevpascalproject/run/globaldebugarguments");
 }
 
 
@@ -370,13 +369,6 @@ void PascalProjectPart::slotExecute()
     for (it = envvars.begin(); it != envvars.end(); ++it) {
         environstr += (*it).first;
         environstr += "=";
-/*
-#if (KDE_VERSION > 305)
-        environstr += KProcess::quote((*it).second);
-#else
-        environstr += KShellProcess::quote((*it).second);
-#endif
-*/
         environstr += EnvVarTools::quote((*it).second);
         environstr += " ";
     }
@@ -408,7 +400,6 @@ void PascalProjectPart::projectConfigWidget( KDialogBase * dlg )
 
     vbox = dlg->addVBoxPage(i18n("Run Options"), i18n("Run Options"), BarIcon( "make", KIcon::SizeMedium ));
     RunOptionsWidget *w3 = new RunOptionsWidget(*projectDom(), "/kdevpascalproject", buildDirectory(), vbox);
-    w3->mainprogram_label->setText(i18n("Main program (relative to project directory):"));
     connect( dlg, SIGNAL(okClicked()), w3, SLOT(accept()) );
 
 }
