@@ -40,7 +40,6 @@
 #include <qregexp.h>
 #include <qvalidator.h>
 #include <qtabwidget.h>
-#include <pathutil.h>
 #include <kpushbutton.h>
 #include <kcombobox.h>
 #include <klocale.h>
@@ -50,6 +49,7 @@
 #include "trollprojectpart.h"
 #include "qmakescopeitem.h"
 #include "scope.h"
+#include "urlutil.h"
 
 InsideCheckListItem::InsideCheckListItem( QListView *parent, QMakeScopeItem *item, ProjectConfigurationDlg *config ) :
         QCheckListItem( parent, item->relativePath().right( item->relativePath().length() - 1 ), QCheckListItem::CheckBox )
@@ -109,6 +109,16 @@ ProjectConfigurationDlg::ProjectConfigurationDlg( QListView *_prjList, TrollProj
                                               QRegExp( "\\d+(\\.\\d+)?(\\.\\d+)" ), this ) );
     customVariables->setSortColumn(0);
     customVariables->setSortOrder(Qt::Ascending);
+    mocdir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
+    mocdir_url->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
+    objdir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
+    objdir_url->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
+    rccdir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
+    rccdir_url->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
+    uidir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
+    uidir_url->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
+    m_CWDEdit->completionObject()->setMode(KURLCompletion::DirCompletion);
+    m_CWDEdit->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
 }
 
 void ProjectConfigurationDlg::updateSubproject( QMakeScopeItem* _item )
@@ -141,7 +151,7 @@ ProjectConfigurationDlg::~ProjectConfigurationDlg()
 
 void ProjectConfigurationDlg::browseTargetPath()
 {
-    m_targetPath->setText( getRelativePath( myProjectItem->scope->projectDir(), KFileDialog::getExistingDirectory() ) );
+    m_targetPath->setText( URLUtil::getRelativePath( myProjectItem->scope->projectDir(), KFileDialog::getExistingDirectory() ) );
     buttonApply->setEnabled( false );
 }
 
@@ -164,6 +174,16 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
             if( myProjectItem->scope->variableValues( "CONFIG" ).findIndex( "dll" ) != -1 )
                 myProjectItem->scope->removeFromPlusOp( "CONFIG", "dll" );
             myProjectItem->setPixmap( 0, SmallIcon( "qmake_app" ) );
+            QString targetname = prjWidget->getCurrentOutputFilename();
+            if( targetname.findRev("/") != -1 )
+                targetname = targetname.right( targetname.length() - targetname.findRev("/") - 1 );
+            DomUtil::writeEntry( *prjWidget->m_part->projectDom(),
+                                 "/kdevtrollproject/run/runarguments/"+targetname, m_editRunArguments->text() );
+            DomUtil::writeEntry( *prjWidget->m_part->projectDom(),
+                                 "/kdevtrollproject/run/cwd/"+targetname, m_CWDEdit->url() );
+            DomUtil::writeEntry( *prjWidget->m_part->projectDom(),
+                                 "/kdevtrollproject/run/debugarguments/"+targetname, m_editDebugArguments->text() );
+
         }
         else if ( radioLibrary->isChecked() )
         {
@@ -270,24 +290,11 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
         myProjectItem->addValue( "CONFIG", "ordered" );
     else
         myProjectItem->removeValue( "CONFIG", "ordered" );
-    QString libtoolconf;
-    if ( prjWidget->m_part->isQt4Project() )
-        libtoolconf = "create_libtool";
-    else
-        libtoolconf = "compile_libtool";
     if ( checkLibtool->isChecked() )
-        myProjectItem->addValue( "CONFIG", libtoolconf );
+        myProjectItem->addValue( "CONFIG", "compile_libtool" );
     else
-        myProjectItem->removeValue( "CONFIG", libtoolconf );
-    QString pkgconfenable;
-    if ( prjWidget->m_part->isQt4Project() )
-        pkgconfenable = "create_pkgconf";
-    else
-        pkgconfenable = "create_pc";
-    if ( checkPkgconf->isChecked() )
-        myProjectItem->addValue( "CONFIG", pkgconfenable );
-    else
-        myProjectItem->removeValue( "CONFIG", pkgconfenable );
+        myProjectItem->removeValue( "CONFIG", "compile_libtool" );
+
     if ( checkConsole->isChecked() )
         myProjectItem->addValue( "CONFIG", "console" );
     else
@@ -428,6 +435,7 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
         values << outsideItem->text( 0 );
         outsideItem = ( QCheckListItem* ) outsideItem->itemBelow();
     }
+    myProjectItem->removeValues( "INCLUDEPATH", values );
     myProjectItem->updateValues( "INCLUDEPATH", values );
 
     //target.install
@@ -492,6 +500,7 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
     }
 
 
+    myProjectItem->removeValues( "LIBS", values );
     myProjectItem->updateValues( "LIBS", values );
 
     values.clear();
@@ -530,6 +539,7 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
         }
         insideItem = dynamic_cast<InsideCheckListItem *>( insideItem->itemBelow() );
     }
+    myProjectItem->removeValues( "TARGETDEPS", values );
     myProjectItem->updateValues( "TARGETDEPS", values );
 
     values.clear();
@@ -567,6 +577,13 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
     //CORBA
     myProjectItem->scope->setEqualOp( "IDL_COMPILER", QStringList( idlCmdEdit->url() ) );
     myProjectItem->updateValues( "IDL_OPTIONS", QStringList::split( " ", idlCmdOptionsEdit->text() ) );
+
+    QListViewItemIterator iter(customVariables);
+    for( ; iter.current() ; iter++ )
+    {
+        QListViewItem* item = iter.current();
+        myProjectItem->scope->updateCustomVariable( item->key(0, true).toUInt(), item->text(0), item->text(1), item->text(2) );
+    }
 }
 
 void ProjectConfigurationDlg::accept()
@@ -629,7 +646,11 @@ void ProjectConfigurationDlg::updateControls()
         }
 
         if( !staticRadio->isChecked() && !sharedRadio->isChecked() )
+	{
             staticRadio->setChecked( true );
+            checkPlugin->setEnabled( false );
+            checkDesigner->setEnabled( false );
+	}
 
         if ( configValues.findIndex( "plugin" ) != -1 )
             checkPlugin->setChecked( true );
@@ -639,14 +660,10 @@ void ProjectConfigurationDlg::updateControls()
             checkDesigner->setChecked( true );
         else
             checkDesigner->setChecked( false );
-        if ( configValues.findIndex( "create_libtool" ) != -1 )
+        if ( configValues.findIndex( "compile_libtool" ) != -1 )
             checkLibtool->setChecked( true );
         else
             checkLibtool->setChecked( false );
-        if ( configValues.findIndex( "create_pkgconf" ) != -1 )
-            checkPkgconf->setChecked( true );
-        else
-            checkPkgconf->setChecked( false );
     }
     else if ( templateValues.findIndex( "subdirs" ) != -1 )
     {
@@ -659,6 +676,21 @@ void ProjectConfigurationDlg::updateControls()
         {
             checkConsole->setChecked( true );
         }
+        QString targetname = prjWidget->getCurrentOutputFilename();
+        if( targetname.findRev("/") != -1 )
+            targetname = targetname.right( targetname.length() - targetname.findRev("/") - 1 );
+        m_editRunArguments->setText( DomUtil::readEntry( *prjWidget->m_part->projectDom(), "/kdevtrollproject/run/runarguments/"+targetname, "" ) );
+        m_CWDEdit->setURL( DomUtil::readEntry( *prjWidget->m_part->projectDom(), "/kdevtrollproject/run/cwd/"+targetname, "" ) );
+        m_CWDEdit->fileDialog()->setURL( KURL::fromPathOrURL( DomUtil::readEntry( *prjWidget->m_part->projectDom(), "/kdevtrollproject/run/cwd/"+targetname, "" ) ) );
+        if( m_CWDEdit->url().isEmpty() )
+        {
+            QString destdir = myProjectItem->m_widget->getCurrentDestDir();
+            if( !destdir.startsWith( "/" ) )
+                destdir = myProjectItem->m_widget->projectDirectory()+"/"+destdir;
+            m_CWDEdit->setURL( destdir.left( destdir.findRev("/") ) );
+            m_CWDEdit->fileDialog()->setURL( KURL::fromPathOrURL( destdir.left( destdir.findRev("/") ) ) );
+        }
+        m_editDebugArguments->setText( DomUtil::readEntry( *prjWidget->m_part->projectDom(), "/kdevtrollproject/run/debugarguments/"+targetname, "" ) );
     }
 
     // Buildmode
@@ -933,8 +965,10 @@ void ProjectConfigurationDlg::updateLibControls()
 
     insidelib_listview->setSorting( -1, false );
     outsidelib_listview->setSorting( -1, false );
+    outsidelibdir_listview->setSorting( -1, false );
     insidelib_listview->clear();
     outsidelib_listview->clear();
+    outsidelibdir_listview->clear();
     //update librarys
     //temp strlist
     QStringList libList = myProjectItem->scope->variableValues( "LIBS" );
@@ -967,8 +1001,6 @@ void ProjectConfigurationDlg::updateLibControls()
     }
 
     //all other in libList are outside libs
-    outsidelib_listview->clear();
-    outsidelibdir_listview->clear();
     QStringList::Iterator it1 = libList.begin();
     for ( ;it1 != libList.end();++it1 )
     {
@@ -1161,13 +1193,18 @@ void ProjectConfigurationDlg::outsideIncMoveDownClicked()
 void ProjectConfigurationDlg::outsideIncAddClicked()
 {
     KURLRequesterDlg dialog( "", i18n( "Add include directory:" ), 0, 0 );
-    dialog.urlRequester() ->setMode( KFile::Directory );
+    dialog.urlRequester() ->setMode( KFile::Directory | KFile::LocalOnly );
+    dialog.urlRequester() ->setURL( QString::null );
+    dialog.urlRequester() ->completionObject() ->setDir( myProjectItem->scope->projectDir() );
+    dialog.urlRequester() ->fileDialog() ->setURL( KURL( myProjectItem->scope->projectDir() ) );
     if ( dialog.exec() != QDialog::Accepted )
         return ;
     QString dir = dialog.urlRequester() ->url();
     if ( !dir.isEmpty() )
+    {
         new QListViewItem( outsideinc_listview, dir );
-    activateApply( 0 );
+        activateApply( 0 );
+    }
 }
 
 
@@ -1243,22 +1280,29 @@ void ProjectConfigurationDlg::outsideLibAddClicked()
     dialog.urlRequester() ->setFilter( "*.so|"+i18n("Shared Library (*.so)")+"\n*.a|"+i18n("Static Library (*.a)") );
     dialog.urlRequester() ->setURL( QString::null );
     dialog.urlRequester() ->completionObject() ->setDir( myProjectItem->scope->projectDir() );
-
+    dialog.urlRequester() ->fileDialog() ->setURL( KURL( myProjectItem->scope->projectDir() ) );
     if ( dialog.exec() != QDialog::Accepted )
         return ;
     QString file = dialog.urlRequester() ->url();
     if ( !file.isEmpty() )
     {
         if( file.startsWith("-l") )
+        {
             new QListViewItem( outsidelib_listview, file );
+            activateApply( 0 );
+        }
         else
         {
             QFileInfo fi(file);
             if( !fi.exists() )
-                return;
+            {
+                new QListViewItem( outsidelib_listview, file );;
+                activateApply( 0 );
+            }
             if( fi.extension(false) == "a" )
             {
                 new QListViewItem( outsidelib_listview, file );
+                activateApply( 0 );
             }else if ( fi.extension(false) == "so" )
             {
                 QString path = fi.dirPath( true );
@@ -1268,10 +1312,11 @@ void ProjectConfigurationDlg::outsideLibAddClicked()
                 name = "-l"+name.left( name.length() - 3 );
                 new QListViewItem( outsidelib_listview, name );
                 new QListViewItem( outsidelibdir_listview, path );
+                activateApply( 0 );
             }else
                 return;
         }
-        activateApply( 0 );
+
     }
 }
 
@@ -1315,13 +1360,18 @@ void ProjectConfigurationDlg::outsideLibDirMoveDownClicked()
 void ProjectConfigurationDlg::outsideLibDirAddClicked()
 {
     KURLRequesterDlg dialog( "", i18n( "Add library directory:" ), 0, 0 );
-    dialog.urlRequester() ->setMode( KFile::Directory );
+    dialog.urlRequester() ->setMode( KFile::Directory | KFile::LocalOnly );
+    dialog.urlRequester() ->setURL( QString::null );
+    dialog.urlRequester() ->completionObject() ->setDir( myProjectItem->scope->projectDir() );
+    dialog.urlRequester() ->fileDialog() ->setURL( KURL( myProjectItem->scope->projectDir() ) );
     if ( dialog.exec() != QDialog::Accepted )
         return ;
     QString dir = dialog.urlRequester() ->url();
     if ( !dir.isEmpty() )
+    {
         new QListViewItem( outsidelibdir_listview, dir );
-    activateApply( 0 );
+        activateApply( 0 );
+    }
 }
 
 
@@ -1338,26 +1388,76 @@ void ProjectConfigurationDlg::outsideIncEditClicked()
     QString text = item->text( 0 );
 
     KURLRequesterDlg dialog( text, i18n( "Change include directory:" ), 0, 0 );
-    dialog.urlRequester() ->setMode( KFile::Directory );
+    dialog.urlRequester() ->setMode( KFile::Directory | KFile::LocalOnly );
+    if( !text.startsWith( "/" ) )
+    {
+        dialog.urlRequester() ->completionObject() ->setDir( myProjectItem->scope->projectDir()+text );
+        dialog.urlRequester() ->fileDialog() ->setURL( KURL( myProjectItem->scope->projectDir()+text ) );
+        dialog.urlRequester() ->setURL( myProjectItem->scope->projectDir()+text );
+    }
+    else
+    {
+        dialog.urlRequester() ->completionObject() ->setDir( text );
+        dialog.urlRequester() ->fileDialog() ->setURL( KURL( text ) );
+        dialog.urlRequester() ->setURL( text );
+    }
     if ( dialog.exec() != QDialog::Accepted )
         return ;
     QString dir = dialog.urlRequester() ->url();
     if ( !dir.isEmpty() )
+    {
         item->setText( 0, dir );
-    activateApply( 0 );
+        activateApply( 0 );
+    }
 }
 
 void ProjectConfigurationDlg::outsideLibEditClicked()
 {
-    bool ok;
     QListViewItem *item = outsidelib_listview->currentItem();
     if ( item == NULL ) return ;
     QString text = item->text( 0 );
 
-    QString dir = KInputDialog::getText( i18n( "Change Library" ), i18n( "Change library to link:" ), text, &ok, 0 );
-    if ( ok && !dir.isEmpty() && dir != "-l" )
-        item->setText( 0, dir );
-    activateApply( 0 );
+    KURLRequesterDlg dialog( text, i18n( "Change Library:" ), 0, 0 );
+    dialog.urlRequester() ->setMode( KFile::File | KFile::ExistingOnly | KFile::LocalOnly );
+        dialog.urlRequester() ->completionObject() ->setDir( text );
+        dialog.urlRequester() ->fileDialog() ->setURL( KURL( text ) );
+        dialog.urlRequester() ->setURL( text );
+    if ( dialog.exec() != QDialog::Accepted )
+        return ;
+    QString file = dialog.urlRequester() ->url();
+    if ( !file.isEmpty() )
+    {
+        if( file.startsWith("-l") )
+        {
+            item->setText( 0, file );
+            activateApply( 0 );
+        }
+        else
+        {
+            QFileInfo fi(file);
+            if( !fi.exists() )
+            {
+                item->setText( 0, file );
+                activateApply( 0 );
+            }
+            if( fi.extension(false) == "a" )
+            {
+                item->setText( 0, file );
+                activateApply( 0 );
+            }else if ( fi.extension(false) == "so" )
+            {
+                QString path = fi.dirPath( true );
+                QString name = fi.fileName();
+                if( name.startsWith( "lib" ) )
+                    name = name.mid(3);
+                name = "-l"+name.left( name.length() - 3 );
+                item->setText( 0, name );
+                new QListViewItem( outsidelibdir_listview, path );
+                activateApply( 0 );
+            }else
+                return;
+        }
+    }
 }
 
 void ProjectConfigurationDlg::outsideLibDirEditClicked()
@@ -1367,26 +1467,46 @@ void ProjectConfigurationDlg::outsideLibDirEditClicked()
     QString text = item->text( 0 );
 
     KURLRequesterDlg dialog( text, i18n( "Change library directory:" ), 0, 0 );
-    dialog.urlRequester() ->setMode( KFile::Directory );
+    dialog.urlRequester() ->setMode( KFile::Directory | KFile::LocalOnly );
+
+    if( !text.startsWith( "/" ) )
+    {
+        dialog.urlRequester() ->completionObject() ->setDir( myProjectItem->scope->projectDir()+text );
+        dialog.urlRequester() ->fileDialog() ->setURL( KURL( myProjectItem->scope->projectDir()+text ) );
+        dialog.urlRequester() ->setURL( myProjectItem->scope->projectDir()+text );
+    }
+    else
+    {
+        dialog.urlRequester() ->completionObject() ->setDir( text );
+        dialog.urlRequester() ->fileDialog() ->setURL( KURL( text ) );
+        dialog.urlRequester() ->setURL( text );
+    }
     if ( dialog.exec() != QDialog::Accepted )
         return ;
     QString dir = dialog.urlRequester() ->url();
     if ( !dir.isEmpty() )
+    {
         item->setText( 0, dir );
-    activateApply( 0 );
+        activateApply( 0 );
+    }
 }
 
 
 void ProjectConfigurationDlg::extAdd_button_clicked( )
 {
     KURLRequesterDlg dialog( "", i18n( "Add target:" ), 0, 0 );
-    dialog.urlRequester() ->setMode( KFile::File );
+    dialog.urlRequester() ->setMode( KFile::File | KFile::LocalOnly );
+    dialog.urlRequester() ->setURL( QString::null );
+    dialog.urlRequester() ->completionObject() ->setDir( myProjectItem->scope->projectDir() );
+    dialog.urlRequester() ->fileDialog() ->setURL( KURL( myProjectItem->scope->projectDir() ) );
     if ( dialog.exec() != QDialog::Accepted )
         return ;
     QString path = dialog.urlRequester() ->url();
     if ( !path.isEmpty() )
+    {
         new QListViewItem( extDeps_view, path );
-    activateApply( 0 );
+        activateApply( 0 );
+    }
 }
 
 void ProjectConfigurationDlg::extEdit_button_clicked( )
@@ -1396,13 +1516,26 @@ void ProjectConfigurationDlg::extEdit_button_clicked( )
     QString text = item->text( 0 );
 
     KURLRequesterDlg dialog( text, i18n( "Change target:" ), 0, 0 );
-    dialog.urlRequester() ->setMode( KFile::File );
+    dialog.urlRequester() ->setMode( KFile::File | KFile::LocalOnly );
+    dialog.urlRequester() ->setURL( QString::null );
+    if( !text.startsWith( "/" ) )
+    {
+        dialog.urlRequester() ->completionObject() ->setDir( myProjectItem->scope->projectDir()+text );
+        dialog.urlRequester() ->fileDialog() ->setURL( KURL( myProjectItem->scope->projectDir()+text ) );
+    }
+    else
+    {
+        dialog.urlRequester() ->completionObject() ->setDir( text );
+        dialog.urlRequester() ->fileDialog() ->setURL( KURL( text ) );
+    }
     if ( dialog.exec() != QDialog::Accepted )
         return ;
     QString path = dialog.urlRequester() ->url();
     if ( !path.isEmpty() )
+    {
         item->setText( 0, path );
-    activateApply( 0 );
+        activateApply( 0 );
+    }
 }
 
 void ProjectConfigurationDlg::extMoveDown_button_clicked( )
@@ -1502,18 +1635,7 @@ void ProjectConfigurationDlg::removeCustomValueClicked()
 
     activateApply( 0 );
 }
-void ProjectConfigurationDlg::editCustomValueClicked()
-{
-    QListViewItem * item = customVariables->currentItem();
-    if ( item )
-    {
-        item->setText( 0, customVariableName->text() );
-        item->setText( 1, customVariableOp->currentText() );
-        item->setText( 2, customVariableData->text() );
-        myProjectItem->scope->updateCustomVariable( item->key(0, true).toUInt(), item->text(0), item->text(1), item->text(2) );
-    }
-    activateApply( 0 );
-}
+
 void ProjectConfigurationDlg::upCustomValueClicked()
 {
     // custom vars
@@ -1542,6 +1664,9 @@ void ProjectConfigurationDlg::downCustomValueClicked()
 
 void ProjectConfigurationDlg::newCustomVariableActive( )
 {
+    customVariableOp->blockSignals(true);
+    customVariableName->blockSignals(true);
+    customVariableData->blockSignals(true);
     QListViewItem * item = customVariables->currentItem();
     if ( item )
     {
@@ -1550,6 +1675,9 @@ void ProjectConfigurationDlg::newCustomVariableActive( )
         customVariableOp->setCurrentText( item->text( 1 ) );
         customVariableName->setFocus();
     }
+    customVariableOp->blockSignals(false);
+    customVariableName->blockSignals(false);
+    customVariableData->blockSignals(false);
 }
 
 void ProjectConfigurationDlg::groupLibrariesChanged( int )
@@ -1836,4 +1964,16 @@ void ProjectConfigurationDlg::addAppDeps()
     }
 }
 
+void ProjectConfigurationDlg::customVarChanged()
+{
+    QListViewItem * item = customVariables->currentItem();
+    if ( item )
+    {
+        item->setText( 0, customVariableName->text() );
+        item->setText( 1, customVariableOp->currentText() );
+        item->setText( 2, customVariableData->text() );
+    }
+    activateApply( 0 );
+}
+
 // kate: space-indent on; indent-width 4; tab-width 4; replace-tabs on
