@@ -14,6 +14,7 @@
 #include "qmakescopeitem.h"
 
 #include <qdir.h>
+#include <qregexp.h>
 
 #include <kiconloader.h>
 #include <klocale.h>
@@ -21,7 +22,7 @@
 #include <kdirwatch.h>
 
 #include "scope.h"
-#include "pathutil.h"
+#include "urlutil.h"
 #include "trollprojectwidget.h"
 /*
  * Class qProjectItem
@@ -51,7 +52,7 @@ GroupItem::GroupItem( QListView *lv, GroupType type, const QString &text, QMakeS
     setPixmap( 0, SmallIcon( "tar" ) );
 }
 
-GroupItem::GroupType GroupItem::groupTypeForExtension( const QString &ext )
+GroupItem::GroupType GroupItem::groupTypeForExtension( const QString &ext, bool qt4project )
 {
     if ( ext == "cpp" || ext == "cc" || ext == "c" || ext == "C" || ext == "c++" || ext == "cxx" || ext == "ocl" )
         return Sources;
@@ -59,7 +60,7 @@ GroupItem::GroupType GroupItem::groupTypeForExtension( const QString &ext )
         return Headers;
     else if ( ext == "ui" )
         return Forms;
-    else if ( ext == "jpg" || ext == "jpeg" || ext == "png" || ext == "xpm" || ext == "gif" || ext == "bmp" )
+    else if ( qt4project && ( ext == "jpg" || ext == "jpeg" || ext == "png" || ext == "xpm" || ext == "gif" || ext == "bmp" ) )
         return Images;
     else if ( ext == "idl" )
         return IDLs;
@@ -72,7 +73,7 @@ GroupItem::GroupType GroupItem::groupTypeForExtension( const QString &ext )
     else if ( ext == "qrc" )
         return Resources;
     else
-        return NoType;
+        return Distfiles;
 }
 
 void GroupItem::groupTypeMeanings( GroupItem::GroupType type, QString& title, QString& ext )
@@ -147,52 +148,59 @@ void GroupItem::paintCell( QPainter* p, const QColorGroup& c, int column, int wi
 
 void GroupItem::addFileToScope( const QString& filename )
 {
+    QString file = filename;
+    if( filename.find(QRegExp("[ \t]") ) != -1 )
+        file = "\""+file+"\"";
+
     QPtrListIterator<FileItem> it( files );
     while ( it.current() != 0 )
     {
-        if ( it.current() ->text( 0 ) == filename )      //File already exists in this subproject
+        if ( it.current() ->text( 0 ) == file )      //File already exists in this subproject
             return ;
         ++it;
     }
 
-    FileItem *fitem = owner->createFileItem( filename );
+    FileItem *fitem = owner->createFileItem( file );
 
     fitem->uiFileLink = owner->m_widget->getUiFileLink( owner->relativePath() + QString( QChar( QDir::separator() ) ), owner->scope->resolveVariables( filename ) );
     files.append( fitem );
     switch ( groupType )
     {
         case GroupItem::Sources:
-            owner->addValue( "SOURCES", filename );
+            owner->addValue( "SOURCES", file );
             break;
         case GroupItem::Headers:
-            owner->addValue( "HEADERS", filename );
+            owner->addValue( "HEADERS", file );
             break;
         case GroupItem::Forms:
-            owner->addValue( "FORMS", filename );
+        if( owner->m_widget->isTMakeProject() )
+                owner->addValue( "INTERFACES", file );
+            else
+                owner->addValue( "FORMS", file );
             break;
         case GroupItem::IDLs:
-            owner->addValue( "IDLS", filename );
+            owner->addValue( "IDLS", file );
             break;
         case GroupItem::Lexsources:
-            owner->addValue( "LEXSOURCES", filename );
+            owner->addValue( "LEXSOURCES", file );
             break;
         case GroupItem::Yaccsources:
-            owner->addValue( "YACCSOURCES", filename );
+            owner->addValue( "YACCSOURCES", file );
             break;
         case GroupItem::Images:
-            owner->addValue( "IMAGES", filename );
+            owner->addValue( "IMAGES", file );
             break;
         case GroupItem::Resources:
-            owner->addValue( "RESOURCES", filename );
+            owner->addValue( "RESOURCES", file );
             break;
         case GroupItem::Distfiles:
-            owner->addValue( "DISTFILES", filename );
+            owner->addValue( "DISTFILES", file );
             break;
         case GroupItem::Translations:
-            owner->addValue( "TRANSLATIONS", filename );
+            owner->addValue( "TRANSLATIONS", file );
             break;
         case GroupItem::InstallObject:
-            owner->addValue( text( 0 ) + ".files", filename );
+            owner->addValue( text( 0 ) + ".files", file );
             break;
         default:
             break;
@@ -270,6 +278,14 @@ void GroupItem::addInstallObject( const QString& objectname )
     installs.append( objitem );
 }
 
+void GroupItem::removeInstallObject( GroupItem* item )
+{
+    owner->removeValue( "INSTALLS", item->text(0) );
+    owner->scope->saveToFile();
+    installs.remove( item );
+    delete item;
+}
+
 /*
  * Class FileItem
  */
@@ -319,7 +335,7 @@ QString QMakeScopeItem::relativePath()
     if( !scope || !scope->parent() )
         return "";
     if( scope->scopeType() == Scope::ProjectScope )
-        return getRelativePath( m_widget->projectDirectory(), scope->projectDir() );
+        return URLUtil::getRelativePath( m_widget->projectDirectory(), scope->projectDir() );
     else
         return static_cast<QMakeScopeItem*>( parent() ) ->relativePath();
 //     if( !scope->parent() )
@@ -337,7 +353,7 @@ QString QMakeScopeItem::getSharedLibAddObject( QString basePath )
 {
     if ( scope->variableValues( "CONFIG" ).findIndex( "dll" ) != -1 )
     {
-        QString tmpPath = getRelativePath(basePath, scope->projectDir() );
+        QString tmpPath = URLUtil::getRelativePath(basePath, scope->projectDir() );
         if ( !scope->variableValues( "DESTDIR" ).front().isEmpty() )
         {
             if ( QDir::isRelativePath( scope->variableValues( "DESTDIR" ).front() ) )
@@ -370,7 +386,7 @@ QString QMakeScopeItem::getSharedLibAddObject( QString basePath )
 
 QString QMakeScopeItem::getApplicationObject( QString basePath )
 {
-    QString tmpPath = getRelativePath(basePath, scope->projectDir() );
+    QString tmpPath = URLUtil::getRelativePath(basePath, scope->projectDir() );
     if ( !scope->variableValues( "DESTDIR" ).front().isEmpty() )
     {
         if ( QDir::isRelativePath( scope->variableValues( "DESTDIR" ).front() ) )
@@ -407,7 +423,7 @@ QString QMakeScopeItem::getLibAddObject( QString basePath )
     else if ( scope->variableValues( "CONFIG" ).findIndex( "staticlib" ) != -1
             || scope->variableValues("TEMPLATE").findIndex("lib") != -1 )
     {
-        QString tmpPath = getRelativePath(basePath, scope->projectDir() );
+        QString tmpPath = URLUtil::getRelativePath(basePath, scope->projectDir() );
         if ( !scope->variableValues( "DESTDIR" ).front().isEmpty() )
         {
             if ( QDir::isRelativePath( scope->variableValues( "DESTDIR" ).front() ) )
@@ -444,7 +460,7 @@ QString QMakeScopeItem::getLibAddPath( QString basePath )
     //PATH only add if shared lib
     if ( scope->variableValues( "CONFIG" ).findIndex( "dll" ) == -1 ) return ( "" );
 
-    QString tmpPath = getRelativePath(basePath, scope->projectDir() );
+    QString tmpPath = URLUtil::getRelativePath(basePath, scope->projectDir() );
     if ( !scope->variableValues( "DESTDIR" ).front().isEmpty() )
     {
         if ( QDir::isRelativePath( scope->variableValues( "DESTDIR" ).front() ) )
@@ -465,7 +481,7 @@ QString QMakeScopeItem::getLibAddPath( QString basePath )
 
 QString QMakeScopeItem::getIncAddPath( QString basePath )
 {
-    QString tmpPath = getRelativePath( basePath, scope->projectDir() );
+    QString tmpPath = URLUtil::getRelativePath( basePath, scope->projectDir() );
     tmpPath = QDir::cleanDirPath( tmpPath );
 
     return ( tmpPath );
@@ -824,7 +840,7 @@ QMap<QString, QString> QMakeScopeItem::getLibInfos( QString basePath )
     else
         result["shared_lib"] = "-l"+scope->variableValues( "TARGET" ).front();
 
-    QString tmpPath = getRelativePath(basePath, scope->projectDir() );
+    QString tmpPath = URLUtil::getRelativePath(basePath, scope->projectDir() );
     if ( !scope->variableValues( "DESTDIR" ).front().isEmpty() )
     {
         if ( QDir::isRelativePath( scope->variableValues( "DESTDIR" ).front() ) )
