@@ -23,10 +23,9 @@
 
 #include <kdirwatch.h>
 
-#include "pathutil.h"
+#include "urlutil.h"
 #include "trollprojectpart.h"
 #include "qmakedefaultopts.h"
-#include "pathutil.h"
 
 const QStringList Scope::KnownVariables = QStringList() << "QT" << "CONFIG" << "TEMPLATE" << "SUBDIRS" << "VERSION" << "LIBS" << "target.path" << "INSTALLS" << "MAKEFILE" << "TARGETDEPS" << "INCLUDEPATH" << "TARGET" << "DESTDIR" << "DEFINES" << "QMAKE_CXXFLAGS_DEBUG" << "QMAKE_CXXFLAGS_RELEASE" << "OBJECTS_DIR" << "UI_DIR" << "MOC_DIR" << "IDL_COMPILER" << "IDL_OPTIONS" << "RCC_DIR" << "IDLS" << "RESOURCES" << "IMAGES" << "LEXSOURCES" << "DISTFILES" << "YACCSOURCES" << "TRANSLATIONS" << "HEADERS" << "SOURCES" << "INTERFACES" << "FORMS" ;
 
@@ -334,7 +333,7 @@ void Scope::calcValuesFromStatements( const QString& variable, QStringList& resu
 
     if ( scopeType() == FunctionScope || scopeType() == SimpleScope )
     {
-        m_parent->calcValuesFromStatements( variable, result , this->m_root );
+        m_parent->calcValuesFromStatements( variable, result, checkIncParent, this->m_root );
     }
     else if ( scopeType() == IncludeScope && checkIncParent )
     {
@@ -410,7 +409,7 @@ QString Scope::scopeName() const
     {
         if( m_parent && QDir::cleanDirPath( m_parent->projectDir() ) != QDir::cleanDirPath( projectDir() ) )
         {
-            return getRelativePath( m_parent->projectDir(), projectDir() );
+            return URLUtil::getRelativePath( m_parent->projectDir(), projectDir() );
         }else if ( m_parent && QDir::cleanDirPath( m_parent->projectDir() ) == QDir::cleanDirPath( projectDir() ) )
         {
             return fileName();
@@ -465,8 +464,10 @@ Scope* Scope::createSimpleScope( const QString& scopename )
     ast->setDepth( m_root->depth() );
     m_root->addChildAST( ast );
     m_root->addChildAST( new QMake::NewLineAST() );
+    /* We can't unconditionally add the scope name to CONFIG, scope might be win32 which may only be in CONFIG under windows.
     if ( m_part->isQt4Project() )
         addToPlusOp( "CONFIG", QStringList( scopename ) );
+    */
     Scope* simpleScope = new Scope( getNextScopeNum(), this, ast, m_defaultopts, m_part );
 
     if( simpleScope->scopeType() != Scope::InvalidScope )
@@ -638,7 +639,7 @@ bool Scope::deleteSubProject( unsigned int num, bool deleteSubdir )
     if ( it != m_root->m_children.end() )
     {
         QMake::AssignmentAST * tempast = static_cast<QMake::AssignmentAST*>( *it );
-        if ( tempast->values.findIndex( "subdirs" ) != -1 )
+        if ( tempast->values.findIndex( "subdirs" ) != -1 || findExistingVariable( "TEMPLATE" ) != m_root->m_children.end() )
         {
             Scope* project = m_scopes[ num ];
             if( !project )
@@ -979,7 +980,7 @@ const QMap<unsigned int, QMap<QString, QString> > Scope::customVariables() const
         QMap<QString,QString> temp;
         temp[ "var" ] = it.data()->scopedID;
         temp[ "op" ] = it.data()->op;
-        temp[ "values" ] = it.data()->values.join("");
+        temp[ "values" ] = it.data()->values.join("").stripWhiteSpace();
         result[ it.key() ] = temp;
     }
     return result;
@@ -992,7 +993,7 @@ void Scope::updateCustomVariable( unsigned int id, const QString& name, const QS
     if ( id > 0 && m_customVariables.contains( id ) )
     {
         m_customVariables[ id ] ->values.clear();
-        updateValues( m_customVariables[ id ] ->values, newvalues );
+        updateValues( m_customVariables[ id ] ->values, newvalues.stripWhiteSpace() );
         if( m_varCache.contains( m_customVariables[ id ]->scopedID ) )
             m_varCache.erase( m_customVariables[ id ]->scopedID );
         m_customVariables[ id ] ->op = newop;
@@ -1005,7 +1006,7 @@ unsigned int Scope::addCustomVariable( const QString& var, const QString& op, co
     QMake::AssignmentAST* newast = new QMake::AssignmentAST();
     newast->scopedID = var;
     newast->op = op;
-    newast->values.append(values);
+    newast->values.append(values.stripWhiteSpace());
     if( scopeType() == ProjectScope )
         newast->setDepth( m_root->depth() );
     else
@@ -1210,7 +1211,7 @@ QStringList Scope::resolveVariables( const QStringList& values, QMake::AST* stop
     QMap<QString, QStringList> variables;
     for( QStringList::iterator it = result.begin(); it != result.end(); ++it )
     {
-        QRegExp re("\\$\\$([^\\) /]*)( |\\)|/|$)");
+        QRegExp re("\\$\\$([^{}\\) /]*)( |\\)|/|$)");
         int pos = 0;
         while( pos >= 0 )
         {
@@ -1238,8 +1239,8 @@ QStringList Scope::resolveVariables( const QStringList& values, QMake::AST* stop
         {
             for( QStringList::const_iterator it3 = it2.data().begin(); it3 != it2.data().end(); ++it3 )
             {
-                (*it).replace(QRegExp( "\\$\\$"+it2.key() ), *it3 );
-                (*it).replace(QRegExp( "\\$\\{"+it2.key()+"\\}" ), *it3 );
+                (*it).replace("$$"+it2.key(), *it3 );
+                (*it).replace("$${"+it2.key()+"}", *it3 );
             }
         }
     }
@@ -1248,21 +1249,26 @@ QStringList Scope::resolveVariables( const QStringList& values, QMake::AST* stop
 
 void Scope::allFiles( const QString& projectDirectory, std::set<QString>& res )
 {
-    QString myRelPath = getRelativePath( projectDirectory, projectDir() );
-    if( variableValues("TEMPLATE").findIndex("subdirs") == -1 )
+
+    QString myRelPath = URLUtil::getRelativePath( projectDirectory, projectDir() );
+    QString file;
+    QStringList values;
+    QString header = "";
+    if( variableValues("TEMPLATE",false ).findIndex("subdirs") == -1 )
     {
-        QStringList values = variableValues( "INSTALLS" );
+        values = variableValues( "INSTALLS" ,false );
         QStringList::const_iterator it;
         for ( it = values.begin(); it != values.end(); ++it )
         {
             if ( ( *it ) == "target" )
                 continue;
 
-            QStringList files = variableValues( *it + ".files" );
+            QStringList files = variableValues( *it + ".files" ,false );
             QStringList::iterator filesit = files.begin();
             for ( ;filesit != files.end(); ++filesit )
             {
-                QString file = myRelPath + QString(QChar(QDir::separator())) + *filesit;
+                file = myRelPath + QString(QChar(QDir::separator())) + *filesit;
+                file = resolveVariables( file );
                 if( file.contains("*") )
                 {
                     QFileInfo fi( projectDirectory + QString( QChar( QDir::separator() ) ) + file );
@@ -1272,34 +1278,37 @@ void Scope::allFiles( const QString& projectDirectory, std::set<QString>& res )
                     QStringList list = absDir.entryList();
                     for( QStringList::const_iterator it = list.begin(); it != list.end(); ++it )
                     {
-                        res.insert( getRelativePath( projectDirectory, absDir.path()+QString( QChar( QDir::separator() ) )+*it ) );
+                        res.insert( QDir::cleanDirPath( URLUtil::getRelativePath( projectDirectory, absDir.path()+QString( QChar( QDir::separator() ) )+*it ) ) );
                     }
                 }
                 else
                 {
-                    res.insert( file );
+                    res.insert( QDir::cleanDirPath( file ) );
                 }
             }
         }
 
-        values = variableValues( "LEXSOURCES" );
+        values = variableValues( "LEXSOURCES" ,false );
         for ( it = values.begin(); it != values.end(); ++it )
         {
-            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
-            res.insert( file );
+            file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            file = resolveVariables( file );
+            res.insert( QDir::cleanDirPath( file ) );
         }
 
-        values = variableValues( "YACCSOURCES" );
+        values = variableValues( "YACCSOURCES" ,false );
         for ( it = values.begin(); it != values.end(); ++it )
         {
-            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
-            res.insert( file );
+            file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            file = resolveVariables( file );
+            res.insert( QDir::cleanDirPath( file ) );
         }
 
-        values = variableValues( "DISTFILES" );
+        values = variableValues( "DISTFILES" ,false );
         for ( it = values.begin(); it != values.end(); ++it )
         {
-            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            file = resolveVariables( file );
             if( file.contains("*") )
             {
                 QFileInfo fi( projectDirectory + QString( QChar( QDir::separator() ) ) + file );
@@ -1309,83 +1318,106 @@ void Scope::allFiles( const QString& projectDirectory, std::set<QString>& res )
                 QStringList list = absDir.entryList();
                 for( QStringList::const_iterator it = list.begin(); it != list.end(); ++it )
                 {
-                    res.insert( getRelativePath( projectDirectory, absDir.path()+QString( QChar( QDir::separator() ) )+*it ) );
+                    res.insert( QDir::cleanDirPath( URLUtil::getRelativePath( projectDirectory, absDir.path()+QString( QChar( QDir::separator() ) )+*it ) ) );
                 }
             }
             else
             {
-                res.insert( file );
+                res.insert( QDir::cleanDirPath( file ) );
             }
         }
 
         if ( isQt4Project() )
         {
-            values = variableValues( "RESOURCES" );
+            values = variableValues( "RESOURCES" ,false );
             for ( it = values.begin(); it != values.end(); ++it )
             {
-                QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
-                res.insert( file );
+                file = myRelPath + QString(QChar(QDir::separator())) + *it;
+                file = resolveVariables( file );
+                res.insert( QDir::cleanDirPath( file ) );
             }
         }
         else
         {
-            values = variableValues( "IMAGES" );
+            values = variableValues( "IMAGES" ,false );
             for ( it = values.begin(); it != values.end(); ++it )
             {
-                QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
-                res.insert( file );
+                file = myRelPath + QString(QChar(QDir::separator())) + *it;
+                file = resolveVariables( file );
+                res.insert( QDir::cleanDirPath( file ) );
             }
         }
 
-        values = variableValues( "TRANSLATIONS" );
+        values = variableValues( "TRANSLATIONS" ,false );
         for ( it = values.begin(); it != values.end(); ++it )
         {
-            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
-            res.insert( file );
+            file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            file = resolveVariables( file );
+            res.insert( QDir::cleanDirPath( file ) );
         }
 
-        values = variableValues( "IDLS" );
+        values = variableValues( "IDLS" ,false );
         for ( it = values.begin(); it != values.end(); ++it )
         {
-            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
-            res.insert( file );
+            file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            file = resolveVariables( file );
+            res.insert( QDir::cleanDirPath( file ) );
         }
 
         if ( m_part->isTMakeProject() )
         {
-            values = variableValues( "INTERFACES" );
+            values = variableValues( "INTERFACES" ,false );
             for ( it = values.begin(); it != values.end(); ++it )
             {
-                QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
-                res.insert( file );
+                file = myRelPath + QString(QChar(QDir::separator())) + *it;
+                file = resolveVariables( file );
+                res.insert( QDir::cleanDirPath( file ) );
                 if( QFileInfo(projectDir()+QString(QChar(QDir::separator())) + *it+".h").exists() )
-                    res.insert( file+".h" );
+                    res.insert( QDir::cleanDirPath( file+".h" ) );
             }
         }
         else
         {
-            values = variableValues( "FORMS" );
+            values = variableValues( "FORMS" ,false );
             for ( it = values.begin(); it != values.end(); ++it )
             {
-                QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
-                res.insert( file );
-                if( QFileInfo(projectDir()+QString(QChar(QDir::separator())) + *it+".h").exists() )
-                    res.insert( file+".h" );
+                file = myRelPath + QString(QChar(QDir::separator())) + *it;
+                file = resolveVariables( file );
+                res.insert( QDir::cleanDirPath( file ) );
+
+                if( !m_part->isQt4Project())
+                {
+                    header = projectDir()+QString(QChar(QDir::separator())) + *it+".h";
+                    if( QFileInfo(header).exists() )
+                        res.insert( QDir::cleanDirPath( header ) );
+                    header = projectDir()+QString(QChar(QDir::separator())) + *it+".cpp";
+                    if( QFileInfo(header).exists() )
+                        res.insert( QDir::cleanDirPath( header ) );
+                }
+                else
+                {
+                    header = projectDir()+QString(QChar(QDir::separator())) + "ui_" +*it;
+                    header.replace(QRegExp("\\.ui$"),".h");
+                    if( QFileInfo(header).exists() )
+                        res.insert( QDir::cleanDirPath( header ) );
+                }
             }
         }
 
-        values = variableValues( "SOURCES" );
+        values = variableValues( "SOURCES" ,false );
         for ( it = values.begin(); it != values.end(); ++it )
         {
-            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
-            res.insert( file );
+            file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            file = resolveVariables( file );
+            res.insert( QDir::cleanDirPath( file ) );
         }
 
-        values = variableValues( "HEADERS" );
+        values = variableValues( "HEADERS" ,false );
         for ( it = values.begin(); it != values.end(); ++it )
         {
-            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
-            res.insert( file );
+            file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            file = resolveVariables( file );
+            res.insert( QDir::cleanDirPath( file ) );
         }
     }
     QMap<unsigned int, Scope*>::const_iterator it = m_scopes.begin();
