@@ -49,8 +49,10 @@
 #include "config.h"
 #include "envvartools.h"
 #include "qmakeoptionswidget.h"
+#include "scope.h"
 
 #include <kdevplugininfo.h>
+#include <urlutil.h>
 
 typedef KDevGenericFactory<TrollProjectPart> TrollProjectFactory;
 static const KDevPluginInfo data("kdevtrollproject");
@@ -131,7 +133,7 @@ TrollProjectPart::TrollProjectPart(QObject *parent, const char *name, const QStr
                           this, SLOT(slotBuildAndExecuteProject()),
                           actionCollection(), "build_execute_project" );
     action->setToolTip(i18n("Execute main program"));
-    action->setWhatsThis(i18n("<b>Execute program</b><p>Executes the main program specified in project settings, <b>Run Options</b> tab."));
+    action->setWhatsThis(i18n("<b>Execute program</b><p>Executes the currently selected subproject if its an application or the program specified in project settings, <b>Run Options</b> tab."));
 
     action = new KAction( i18n("&Build Subproject"), "make_kdevelop", Key_F7,
                           m_widget, SLOT(slotBuildTarget()),
@@ -185,6 +187,7 @@ TrollProjectPart::TrollProjectPart(QObject *parent, const char *name, const QStr
 
     QString m_defaultQtDir = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "");
     QString m_qmakePath = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/qmake", "");
+    QString qtversion = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/version", "3");
 
     if( m_defaultQtDir.isEmpty() || !isValidQtDir( m_defaultQtDir ) )
     {
@@ -194,7 +197,9 @@ TrollProjectPart::TrollProjectPart(QObject *parent, const char *name, const QStr
     }
     if( m_qmakePath.isEmpty() || !isExecutable( m_qmakePath ) )
     {
-        m_qmakePath = findExecutable( "qmake" );
+        m_qmakePath = findExecutable( "qmake-qt"+qtversion );
+        if( m_qmakePath.isEmpty() || !isExecutable( m_qmakePath ) )
+            m_qmakePath = findExecutable( "qmake" );
         kdDebug(9024) << "Setting qmake binary to: " << m_qmakePath << endl;
         DomUtil::writeEntry(*projectDom(), "/kdevcppsupport/qt/qmake", m_qmakePath );
     }
@@ -226,13 +231,6 @@ QString TrollProjectPart::makeEnvironment()
 
         environstr += (*it).first;
         environstr += "=";
-/*
-#if (KDE_VERSION > 305)
-        environstr += KProcess::quote((*it).second);
-#else
-        environstr += KShellProcess::quote((*it).second);
-#endif
-*/
         environstr += EnvVarTools::quote((*it).second);
         environstr += " ";
     }
@@ -254,7 +252,7 @@ void TrollProjectPart::projectConfigWidget(KDialogBase *dlg)
     vbox = dlg->addVBoxPage(i18n("Make Options"), i18n("Make Options"), BarIcon( "make", KIcon::SizeMedium ));
     MakeOptionsWidget *w4 = new MakeOptionsWidget(*projectDom(), "/kdevtrollproject", vbox);
 
-    vbox = dlg->addVBoxPage(i18n("QMake Manager Options"), i18n("QMake Manager Options"), BarIcon( "make", KIcon::SizeMedium ));
+    vbox = dlg->addVBoxPage(i18n("QMake Manager"), i18n("QMake Manager"), BarIcon( "make", KIcon::SizeMedium ));
     QMakeOptionsWidget *qm = new QMakeOptionsWidget(*projectDom(), "/kdevtrollproject", vbox);
 
 
@@ -449,25 +447,29 @@ QString TrollProjectPart::runDirectory() const
 {
     QDomDocument &dom = *projectDom();
 
-    QString directoryRadioString = DomUtil::readEntry(dom, "/kdevtrollproject/run/directoryradio");
-    QString DomMainProgram = DomUtil::readEntry(dom, "/kdevtrollproject/run/mainprogram");
-
-    if ( directoryRadioString == "build" )
-        return buildDirectory();
-
-    if ( directoryRadioString == "custom" )
-        return DomUtil::readEntry(dom, "/kdevtrollproject/run/customdirectory");
-
-    int pos = DomMainProgram.findRev(QString( QChar( QDir::separator() ) ));
-    if (pos != -1)
-        return buildDirectory() + QString( QChar( QDir::separator() ) ) + DomMainProgram.left(pos);
-
-    if ( DomMainProgram.isEmpty() )
+    QString cwd;
+    if( DomUtil::readBoolEntry(dom, "/kdevtrollproject/run/useglobalprogram", true) )
     {
-        return m_widget->subprojectDirectory();
+        cwd = defaultRunDirectory("kdevtrollproject");
+    }else
+    {
+        QString name = m_widget->getCurrentOutputFilename();
+        if( name.findRev("/") != -1 )
+            name = name.right( name.length()-name.findRev("/")-1 );
+        cwd = DomUtil::readEntry( dom, "/kdevtrollproject/run/cwd/" + name );
+    }
+    if( cwd.isEmpty() )
+    {
+        QString destpath = m_widget->getCurrentTarget();
+        if( QDir::isRelativePath( destpath ) )
+        {
+            destpath = m_widget->subprojectDirectory() + QString( QChar( QDir::separator() ) ) + destpath;
+        }
+        destpath = destpath.left( destpath.findRev("/") );
+        cwd = destpath;
     }
-    return buildDirectory() + QString( QChar( QDir::separator() ) ) + DomMainProgram;
 
+    return cwd;
 }
 
 
@@ -480,39 +482,77 @@ QString TrollProjectPart::runDirectory() const
   *   if run/directoryradio == custom or relative == false
   *        The absolute path to executable
   */
-QString TrollProjectPart::mainProgram(bool relative) const
+
+
+QString TrollProjectPart::mainProgram() const
 {
+
     QDomDocument &dom = *projectDom();
 
-    QString directoryRadioString = DomUtil::readEntry(dom, "/kdevtrollproject/run/directoryradio");
-    QString DomMainProgram = DomUtil::readEntry(dom, "/kdevtrollproject/run/mainprogram");
+    if( DomUtil::readBoolEntry(dom, "/kdevtrollproject/run/useglobalprogram", true) )
+    {
+        QString DomMainProgram = DomUtil::readEntry(dom, "/kdevtrollproject/run/mainprogram");
 
-    if ( directoryRadioString == "custom" )
-        return DomMainProgram;
+        if ( DomMainProgram.isEmpty() ) return QString();
 
-    if ( relative == false && !DomMainProgram.isEmpty() )
-        return buildDirectory() + QString( QChar( QDir::separator() ) ) + DomMainProgram;
-
-    if ( directoryRadioString == "executable" ) {
-        int pos = DomMainProgram.findRev(QString( QChar( QDir::separator() ) ));
-        if (pos != -1)
-            return DomMainProgram.mid(pos+1);
-
-        if ( DomMainProgram.isEmpty() )
+        if ( DomMainProgram.startsWith("/") )   // assume absolute path
         {
-            return runDirectory() + QString( QChar( QDir::separator() ) ) + m_widget->getCurrentOutputFilename();
+            return DomMainProgram;
         }
-        return DomMainProgram;
+        else // assume project relative path
+        {
+            return projectDirectory() + "/" + DomMainProgram;
+        }
+    }else
+    {
+        if( !m_widget->currentSubproject())
+        {
+            KMessageBox::error( m_widget, "There's no selected subproject!\n"
+                                "Unable to determine the main program", "No selected subproject found" );
+            kdDebug ( 9020 ) << k_funcinfo << "Error! : There's no active target! -> Unable to determine the main program in TrollProjectPart::mainProgram()" << endl;
+            return QString::null;
+        }
+
+        if ( m_widget->currentSubproject()->scope->variableValues("TEMPLATE").findIndex("app") == -1 )
+        {
+            KMessageBox::error( m_widget, "Selected Subproject \""+m_widget->currentSubproject()->scope->projectName()+"\"isn't binary ( " + m_widget->currentSubproject()->scope->variableValues("TEMPLATE").join(" ") + " ) !\n"
+                                "Unable to determine the main program. If you want this\n"
+                                "to be the selected subproject, set a main program under\n"
+                                "Project -> Project Options -> Run Options", "Selected subproject is not a library" );
+            kdDebug ( 9020 ) << k_funcinfo << "Error! : Active target isn't binary (" << m_widget->currentSubproject()->scope->variableValues("TEMPLATE").join(" ") << ") ! -> Unable to determine the main program in TrollProjectPart::mainProgram()" << endl;
+            return QString::null;
+        }
+
+        QString destpath = m_widget->getCurrentTarget();
+        if( QDir::isRelativePath( destpath ) )
+        {
+            destpath = m_widget->subprojectDirectory() + QString( QChar( QDir::separator() ) ) + destpath;
+        }
+        return destpath;
     }
-    else
-        return DomMainProgram;
 }
 
+QString TrollProjectPart::debugArguments() const
+{
+    if( DomUtil::readBoolEntry(*projectDom(), "/kdevtrollproject/run/useglobalprogram", true ) )
+    {
+        return DomUtil::readEntry(*projectDom(), "/kdevtrollproject/run/globaldebugarguments");
+    }else
+    {
+        return DomUtil::readEntry(*projectDom(), "/kdevtrollproject/run/debugarguments/"+m_widget->getCurrentOutputFilename() );
+    }
+}
 
 /** Retuns a QString with the run command line arguments */
 QString TrollProjectPart::runArguments() const
 {
-    return DomUtil::readEntry(*projectDom(), "/kdevtrollproject/run/programargs");
+    if( DomUtil::readBoolEntry(*projectDom(), "/kdevtrollproject/run/useglobalprogram", true) )
+    {
+        return DomUtil::readEntry(*projectDom(), "/kdevtrollproject/run/programargs");
+    }else
+    {
+        return DomUtil::readEntry(*projectDom(), "/kdevtrollproject/run/runarguments/"+m_widget->getCurrentOutputFilename() );
+    }
 }
 
 
