@@ -22,6 +22,7 @@
 #include <qheader.h>
 #include <qcolor.h>
 #include <qlabel.h>
+#include <qlayout.h>
 
 // kde includes
 #include <kdevproject.h>
@@ -32,6 +33,7 @@
 #include <kstandarddirs.h>
 #include <kfileitem.h>
 #include <kurlrequester.h>
+#include <keditlistbox.h>
 #include <klistview.h>
 #include <knuminput.h>
 #include <kmainwindow.h>
@@ -72,16 +74,6 @@ CCConfigWidget::CCConfigWidget( CppSupportPart* part, QWidget* parent, const cha
 	connect( m_qtDir, SIGNAL(textChanged(const QString &)),
 		 this, SLOT(isValidQtDir(const QString &)));
 
-    connect( m_designerPath, SIGNAL(urlSelected(const QString &)),
-         this, SLOT(isExecutable(const QString &)));
-    connect( m_designerPath, SIGNAL(textChanged(const QString &)),
-         this, SLOT(isExecutable(const QString &)));
-
-    connect( m_qmakePath, SIGNAL(urlSelected(const QString &)),
-         this, SLOT(isExecutable(const QString &)));
-    connect( m_qmakePath, SIGNAL(textChanged(const QString &)),
-         this, SLOT(isExecutable(const QString &)));
-
 	initGeneralTab( );
 	initQtTab();
 	initCodeCompletionTab( );
@@ -245,15 +237,7 @@ void CCConfigWidget::slotRemovePCS()
 	KStandardDirs *dirs = m_pPart->instance() ->dirs();
 	QString dbName = dirs->saveLocation( "data", "kdevcppsupport/pcs" ) + KURL::encode_string_no_slash( db ) + ".db";
 
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
-
 	if ( KMessageBox::Continue == KMessageBox::warningContinueCancel( 0, question, i18n( "Delete Database" ), KStdGuiItem::del() ) )
-#else
-
-	if ( KMessageBox::Continue == KMessageBox::warningContinueCancel( 0, question, i18n( "Delete Database" ),
-			KGuiItem( i18n( "&Delete" ), "editdelete", i18n( "Delete item(s)" ) ) ) )
-#endif
-
 	{
 		m_pPart->removeCatalog( dbName );
 	}
@@ -430,6 +414,7 @@ void CCConfigWidget::initQtTab()
         m_qtDir->setEnabled( false );
         m_txtQtDir->setEnabled( false );
         m_txtDesigner->setEnabled( true );
+        pluginPaths->setEnabled( true );
 	}
 	else
 	{
@@ -442,6 +427,7 @@ void CCConfigWidget::initQtTab()
         m_qtDir->setEnabled( true );
         m_txtQtDir->setEnabled( true );
         m_txtDesigner->setEnabled( true );
+        pluginPaths->setEnabled( false );
 	}
 	if( c->includeStyle() == 4 )
 	{
@@ -478,7 +464,7 @@ bool CCConfigWidget::isExecutable( const QString& path )
 
 void CCConfigWidget::isQMakeExecutable( const QString& path )
 {
-    if( isExecutable( path ) )
+    if( !isExecutable( path ) )
     {
         m_qmakePath->lineEdit()->setPaletteForegroundColor(QColor("#ff0000"));
     }else
@@ -489,7 +475,7 @@ void CCConfigWidget::isQMakeExecutable( const QString& path )
 
 void CCConfigWidget::isDesignerExecutable( const QString& path )
 {
-    if( isExecutable( path ) )
+    if( !isExecutable( path ) )
     {
         m_designerPath->lineEdit()->setPaletteForegroundColor(QColor("#ff0000"));
     }else
@@ -557,6 +543,7 @@ void CCConfigWidget::toggleQtVersion( bool )
     m_qtStyleVersion3->setChecked( true );
     m_kdevembedded->setEnabled( true );
     m_kdevexternal->setEnabled( true );
+    pluginPaths->setEnabled( false );
   }
   if ( m_versionQt4->isChecked() )
   {
@@ -564,8 +551,40 @@ void CCConfigWidget::toggleQtVersion( bool )
     m_qtdesigner->setChecked( true );
     m_kdevembedded->setEnabled( false );
     m_kdevexternal->setEnabled( false );
+    pluginPaths->setEnabled( true );
   }
   isValidQtDir( m_qtDir->url() );
+  isQMakeExecutable( m_qmakePath->url() );
+  isDesignerExecutable( m_designerPath->url() );
+}
+
+void CCConfigWidget::openPluginPaths()
+{
+    kdDebug(9024) << "Plugin paths opened" << endl;
+    QtBuildConfig* c = m_pPart->qtBuildConfig();
+    KDialog d( this );
+    QVBoxLayout* mainlayout = new QVBoxLayout( &d );
+    KPushButton* ok = new KPushButton( KStdGuiItem::ok(), &d );
+    connect( ok, SIGNAL(clicked()), &d, SLOT(accept()));
+    KPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), &d );
+    connect( cancel, SIGNAL(clicked()), &d, SLOT(reject()));
+    QHBoxLayout* btns = new QHBoxLayout( &d );
+    btns->addItem( new QSpacerItem(10,10,QSizePolicy::Expanding) );
+    btns->addWidget(ok);
+    btns->addWidget(cancel);
+
+    d.setCaption( i18n( "Edit Qt4 Designer Plugin Paths" ) );
+    KURLRequester * req = new KURLRequester( &d );
+    req->setMode( KFile::Directory );
+    KEditListBox* p = new KEditListBox( i18n( "Plugin Paths" ), req->customEditor(), &d );
+    p->insertStringList( c->designerPluginPaths() );
+    mainlayout->addWidget( p );
+    mainlayout->addLayout( btns );
+    d.resize( 450, 250 );
+    if( d.exec() == QDialog::Accepted)
+    {
+        c->setDesignerPluginPaths( p->items() );
+    }
 }
 
 #include "ccconfigwidget.moc"
