@@ -51,6 +51,7 @@
 // designer integration
 #include "qtdesignercppintegration.h"
 #include "cppimplementationwidget.h"
+#include "configproblemreporter.h"
 
 #include <qeventloop.h>
 #include <qheader.h>
@@ -114,7 +115,7 @@ QStringList CppSupportPart::m_sourceMimeTypes = QStringList() << "text/x-csrc" <
 QStringList CppSupportPart::m_headerMimeTypes = QStringList() << "text/x-chdr" << "text/x-c++hdr";
 
 QStringList CppSupportPart::m_sourceExtensions = QStringList::split( ",", "c,C,cc,cpp,c++,cxx,m,mm,M" );
-QStringList CppSupportPart::m_headerExtensions = QStringList::split( ",", "h,H,hh,hxx,hpp,inl,tlh,diff,ui.h" );
+QStringList CppSupportPart::m_headerExtensions = QStringList::split( ",", "h,H,hh,h++,hxx,hpp,inl,tlh,diff,ui.h" );
 
 class CppDriver: public KDevDriver
 {
@@ -168,10 +169,33 @@ public:
 	}
 };
 
+// ProblemReporter doesn't really depend on background parsing, so it's a bit of a mixup to
+// handle them together, but it's the same config widget so...
+class BackgroundParserConfig
+{
+	bool m_useProblemReporter;
+	bool m_useBackgroundParser;
+	int m_backgroundParseDelay;
+public:
+	void readConfig()
+	{
+		KConfig* config = kapp->config();
+		config->setGroup( "General Options" );
+		m_useProblemReporter = config->readBoolEntry( "EnableProblemReporter", true );
+		m_useBackgroundParser = config->readBoolEntry( "EnableCppBgParser", true );
+		m_backgroundParseDelay = config->readNumEntry( "BgParserDelay", 500 );
+	}
+
+	bool useProblemReporter() { return m_useProblemReporter; }
+	bool useBackgroundParser() { return m_useBackgroundParser; }
+	int backgroudParseDelay() { return m_backgroundParseDelay; }
+};
+
 CppSupportPart::CppSupportPart( QObject *parent, const char *name, const QStringList &args )
-: KDevLanguageSupport( CppSupportFactory::info(), parent, name ? name : "KDevCppSupport" ),
-	m_activeDocument( 0 ), m_activeView( 0 ), m_activeSelection( 0 ), m_activeEditor( 0 ),
-	m_activeViewCursor( 0 ), m_projectClosed( true ), m_projectClosing( false ), m_valid( false ), _jd(0), m_isTyping( false ), m_hadErrors( false )
+: KDevLanguageSupport( CppSupportFactory::info(), parent, name ? name : "KDevCppSupport" ), m_backgroundParser(0),
+	m_activeDocument( 0 ), m_activeView( 0 ), m_activeSelection( 0 ), m_activeEditor( 0 ), m_activeViewCursor( 0 ),
+	m_projectClosed( true ), m_projectClosing( false ), m_valid( false ), m_isTyping( false ), m_hadErrors( false ),
+	_jd(0)
 {
 	setInstance( CppSupportFactory::instance() );
 
@@ -184,14 +208,24 @@ CppSupportPart::CppSupportPart( QObject *parent, const char *name, const QString
 	m_qtBuildConfig = new QtBuildConfig( this, projectDom() );
     m_qtBuildConfig->store();
 
+	m_backgroundParserConfig = new BackgroundParserConfig;
+	m_backgroundParserConfig->readConfig();
+
 	m_driver = new CppDriver( this );
 	m_problemReporter = 0;
 
-	m_deleteParserStoreTimer = new QTimer( this );
+	m_textChangedTimer = new QTimer( this );
+	connect( m_textChangedTimer, SIGNAL(timeout()), this, SLOT(slotParseCurrentFile()) );
+
+	m_cursorMovedTimer = new QTimer( this );
+	connect( m_cursorMovedTimer, SIGNAL(timeout()), this, SLOT(slotCursorPositionChanged()) );
+
+
+// 	m_deleteParserStoreTimer = new QTimer( this );
 	m_saveMemoryTimer = new QTimer( this );
-	m_functionHintTimer = new QTimer( this );
+// 	m_functionHintTimer = new QTimer( this );
 	connect( m_saveMemoryTimer, SIGNAL(timeout()), this, SLOT(slotSaveMemory()) );
-	connect( m_deleteParserStoreTimer, SIGNAL(timeout()), this, SLOT(slotDeleteParserStore()) );
+// 	connect( m_deleteParserStoreTimer, SIGNAL(timeout()), this, SLOT(slotDeleteParserStore()) );
 	resetParserStoreTimer();
 	m_saveMemoryTimer->start( 240000, false ); //Free some memory every 4 minutes
 	//    connect( m_functionHintTimer, SIGNAL(timeout()), this, SLOT(slotFunctionHint()) );
@@ -215,19 +249,19 @@ CppSupportPart::CppSupportPart( QObject *parent, const char *name, const QString
 	connect( core(), SIGNAL( configWidget( KDialogBase* ) ),
 	         this, SLOT( configWidget( KDialogBase* ) ) );
 
-	KAction *action;
-
-	action = new KAction( i18n( "Switch Header/Implementation" ), SHIFT + Key_F12,
+	m_switchHeaderSourceAction = new KAction( i18n( "Switch Header/Implementation" ), SHIFT + Key_F12,
 	                      this, SLOT( slotSwitchHeader() ),
 	                      actionCollection(), "edit_switchheader" );
-	action->setToolTip( i18n( "Switch between header and implementation files" ) );
-	action->setWhatsThis( i18n( "<b>Switch Header/Implementation</b><p>"
+	m_switchHeaderSourceAction->setToolTip( i18n( "Switch between header and implementation files" ) );
+	m_switchHeaderSourceAction->setWhatsThis( i18n( "<b>Switch Header/Implementation</b><p>"
 	                            "If you are currently looking at a header file, this "
 	                            "brings you to the corresponding implementation file. "
 	                            "If you are looking at an implementation file (.cpp etc.), "
 	                            "this brings you to the corresponding header file." ) );
-	action->setEnabled( false );
+	m_switchHeaderSourceAction->setEnabled( false );
 
+	KAction *action;
+	
 	action = new KAction( i18n( "Complete Text" ), CTRL + Key_Space,
 	                      this, SLOT( slotCompleteText() ),
 	                      actionCollection(), "edit_complete_text" );
@@ -303,14 +337,17 @@ CppSupportPart::~CppSupportPart()
 		codeRepository() ->unregisterCatalog( catalog );
 	}
 
-	mainWindow( ) ->removeView( m_problemReporter );
+
+	delete m_backgroundParserConfig;
+	m_backgroundParserConfig = 0;
 
 	delete m_pCompletion;
-	delete m_problemReporter;
-
 	m_pCompletion = 0;
-	m_problemReporter = 0;
 
+/*	mainWindow()->removeView( m_problemReporter );
+	delete m_problemReporter;
+	m_problemReporter = 0;
+*/
 	delete _jd;
 	_jd = 0;
 
@@ -358,8 +395,6 @@ void CppSupportPart::customEvent( QCustomEvent* ev )
 		if( !project()->isProjectFile( fileName ) || !m_parseEmitWaiting.reject( fileName ) ) {
             ParseEmitWaiting::Processed p = m_parseEmitWaiting.processFile( fileName, ( !m_hadErrors && hasErrors && !fromDisk && m_isTyping && fileName == m_activeFileName ) ? ParseEmitWaiting::HadErrors : ParseEmitWaiting::None );
 			parseEmit( p );
-			if( !p.hasFlag( ParseEmitWaiting::Silent ) )
-				emitFileParsed( p );
         } else {
 	        ParseEmitWaiting::Processed p = m_fileParsedEmitWaiting.processFile( fileName );
 	        if( !p.hasFlag( ParseEmitWaiting::Silent ) )
@@ -385,6 +420,12 @@ void CppSupportPart::configWidget( KDialogBase *dlg )
 	                                 BarIcon( info() ->icon(), KIcon::SizeMedium ) );
 	ClassGeneratorConfig *w = new ClassGeneratorConfig( vbox, "classgenerator config widget" );
 	connect( dlg, SIGNAL( okClicked() ), w, SLOT( storeConfig() ) );
+
+	vbox = dlg->addVBoxPage(i18n("C++ Parsing"), i18n("C++ Parsing"),
+	                               BarIcon( "source_cpp", KIcon::SizeMedium) );
+	ConfigureProblemReporter* ww = new ConfigureProblemReporter( vbox );
+	ww->setPart( this );
+	connect(dlg, SIGNAL(okClicked()), ww, SLOT(accept()));
 }
 
 void CppSupportPart::activePartChanged( KParts::Part *part )
@@ -393,11 +434,15 @@ void CppSupportPart::activePartChanged( KParts::Part *part )
 
 	bool enabled = false;
 
-	m_functionHintTimer->stop();
+// 	m_functionHintTimer->stop();
 
 	if ( m_activeView )
 	{
-		disconnect( m_activeView, SIGNAL( cursorPositionChanged() ), this, SLOT( slotCursorPositionChanged() ) );
+		disconnect( m_activeView, SIGNAL( cursorPositionChanged() ), this, 0 );
+	}
+	if ( m_activeDocument )
+	{
+		disconnect( m_activeDocument, SIGNAL(textChanged()), this, 0 );
 	}
 
 	m_isTyping = false;
@@ -406,7 +451,7 @@ void CppSupportPart::activePartChanged( KParts::Part *part )
 	m_activeView = part ? dynamic_cast<KTextEditor::View*>( part->widget() ) : 0;
 	m_activeEditor = dynamic_cast<KTextEditor::EditInterface*>( part );
 	m_activeSelection = dynamic_cast<KTextEditor::SelectionInterface*>( part );
-	m_activeViewCursor = part ? dynamic_cast<KTextEditor::ViewCursorInterface*>( m_activeView ) : 0;
+	m_activeViewCursor = dynamic_cast<KTextEditor::ViewCursorInterface*>( m_activeView );
 
 	m_activeFileName = QString::null;
 
@@ -423,18 +468,22 @@ void CppSupportPart::activePartChanged( KParts::Part *part )
 	actionCollection() ->action( "edit_complete_text" ) ->setEnabled( enabled );
 	actionCollection() ->action( "edit_make_member" ) ->setEnabled( enabled );
 
-	if ( !part )
+	if ( !part || !part->widget() )
 		return ;
 
-	if ( !m_activeView )
-		return ;
+	if ( m_activeDocument )
+	{
+		connect( m_activeDocument, SIGNAL(textChanged()), this, SLOT(slotTextChanged()) );
+		m_textChangedTimer->start( 250, true ); // kick the parse timer, we might want to parse the current file
+	}
 
 	if ( m_activeViewCursor )
 	{
-		connect( m_activeView, SIGNAL( cursorPositionChanged() ),
-		         this, SLOT( slotCursorPositionChanged() ) );
+		connect( m_activeView, SIGNAL( cursorPositionChanged() ), this, SLOT(slotCursorMoved()) );
+// 		         this, SLOT( slotCursorPositionChanged() ) );
 	}
 
+
 #if 0
 	KTextEditor::TextHintInterface* textHintIface = dynamic_cast<KTextEditor::TextHintInterface*>( m_activeView );
 	if ( !textHintIface )
@@ -473,10 +522,7 @@ void CppSupportPart::projectOpened( )
 
 	setupCatalog();
 
-	m_problemReporter = new ProblemReporter( this, 0, "problemReporterWidget" );
-	m_problemReporter->setIcon( SmallIcon( "info" ) );
-	m_problemReporter->setCaption( i18n( "Problem Reporter" ) );
-	mainWindow( ) ->embedOutputView( m_problemReporter, i18n( "Problems" ), i18n( "Problem reporter" ) );
+	embedProblemReporter();
 
 	connect( core(), SIGNAL( configWidget( KDialogBase* ) ),
 	         m_problemReporter, SLOT( configWidget( KDialogBase* ) ) );
@@ -502,6 +548,24 @@ void CppSupportPart::projectOpened( )
 	QTimer::singleShot( 500, this, SLOT( initialParse( ) ) );
 }
 
+void CppSupportPart::embedProblemReporter( bool force )
+{
+	if ( force || m_backgroundParserConfig->useProblemReporter() )
+	{
+		m_problemReporter = new ProblemReporter( this, 0, "problemReporterWidget" );
+		m_problemReporter->setIcon( SmallIcon( "info" ) );
+		m_problemReporter->setCaption( i18n( "Problem Reporter" ) );
+		mainWindow( ) ->embedOutputView( m_problemReporter, i18n( "Problems" ), i18n( "Problem reporter" ) );
+	}
+}
+
+void CppSupportPart::removeProblemReporter()
+{
+	mainWindow()->removeView( m_problemReporter );
+	delete m_problemReporter;
+	m_problemReporter = 0;
+}
+
 
 void CppSupportPart::projectClosed( )
 {
@@ -533,6 +597,8 @@ void CppSupportPart::projectClosed( )
 	delete _jd;
 	_jd = 0;
 
+	removeProblemReporter();
+
 	delete m_pCompletion;
 	m_parseEmitWaiting.clear();
 	m_fileParsedEmitWaiting.clear();
@@ -587,12 +653,7 @@ void CppSupportPart::contextMenu( QPopupMenu *popup, const Context *context )
 	{
 		int id;
 
-		id = popup->insertItem( "Switch header/implementation", this, SLOT( slotSwitchHeader() ) );
-		popup->setWhatsThis( id, i18n( "<b>Switch Header/Implementation</b><p>"
-		                               "If you are currently looking at a header file, this "
-		                               "brings you to the corresponding implementation file. "
-		                               "If you are looking at an implementation file (.cpp etc.), "
-		                               "this brings you to the corresponding header file." ) );
+		m_switchHeaderSourceAction->plug( popup );
 
 		// 	CodeModelItemContext
 		if ( context->type() == Context::EditorContext )
@@ -1044,104 +1105,14 @@ void CppSupportPart::slotSwitchHeader( bool scrollOnly )
 		attemptMatch = config->readBoolEntry( "SwitchShouldMatch", true );
 	}
 
-	static KURL lastSyncedUrl;
-	static int lastSyncedLine = -1;
-
 	// ok, both files exist. Do the codemodel have them?
-	if ( codeModel() ->hasFile( m_activeFileName ) &&
-	     m_activeViewCursor && attemptMatch )
+	if ( codeModel() ->hasFile( m_activeFileName ) && m_activeViewCursor && attemptMatch )
 	{
-		QValueList<FileDom> candidates;
-		if( codeModel()->hasFile( candidate ) ) candidates << codeModel()->fileByName( candidate );
-		FileDom activeFile = codeModel() ->fileByName( m_activeFileName );
-		candidates += activeFile->wholeGroup();
-
-
 		unsigned int currentline, column;
 		m_activeViewCursor->cursorPositionReal( &currentline, &column );
 
-		CodeModelUtils::CodeModelHelper h( codeModel(), activeFile );
-		FunctionDom d = h.functionAt( currentline, column );
-
-		if( d ) {
-			if( d->isFunctionDefinition() ) {
-				///Find the declaration in one of the other files
-				for( QValueList<FileDom>::iterator it = candidates.begin(); it != candidates.end(); ++it ) {
-					FileDom source = *it;
-					// found it. can we find a matching declaration?
-					FunctionList functionList = CodeModelUtils::allFunctionsDetailed( source ).functionList;
-					for ( FunctionList::ConstIterator it_decl = functionList.begin();
-					      it_decl != functionList.end(); ++it_decl )
-					{
-						if( (void*)&(*it_decl) == (void*)d.data() || (scrollOnly && (*it_decl)->fileName() == m_activeFileName ) ) continue;
-						if ( CodeModelUtils::compareDeclarationToDefinition( *it_decl, (FunctionDefinitionModel*)(d.data()) ) )
-						{
-							// found the declaration, let's jump!
-							int line, column;
-							( *it_decl ) ->getStartPosition( &line, &column );
-							KURL url;
-							url.setPath( (*it_decl)->fileName() );
-							if ( scrollOnly ) {
-								KParts::ReadOnlyPart* part = partController()->partForURL( url );
-								uint currentLine = lastSyncedLine;
-								if( part ) {
-									uint col;
-									KTextEditor::ViewCursorInterface *iface = dynamic_cast<KTextEditor::ViewCursorInterface*>(part->widget());
-									if( iface )
-										iface->cursorPosition(  &currentLine, &col );
-								}
-								partController() ->scrollToLineColumn( url, line, -1, lastSyncedLine != currentLine || lastSyncedUrl != url );
-							} else if ( !splitHeaderSourceConfig()->splitEnabled() )
-								partController() ->editDocument( url, line );
-							else
-								partController() ->splitCurrentDocument( url, line );
-							lastSyncedLine = line;
-							lastSyncedUrl = url;
-							return ;
-						}
-					}
-				}
-			} else {
-				///Find the definition in one of the other files
-				for( QValueList<FileDom>::iterator it = candidates.begin(); it != candidates.end(); ++it ) {
-					FileDom source = *it;
-					FunctionDefinitionList functionDefList = CodeModelUtils::allFunctionDefinitionsDetailed( source ).functionList;
-					for ( FunctionDefinitionList::ConstIterator it_def = functionDefList.begin();
-					      it_def != functionDefList.end(); ++it_def )
-					{
-						if( *it_def == d || (scrollOnly && (*it_def)->fileName() == m_activeFileName ) ) continue;
-
-						if ( CodeModelUtils::compareDeclarationToDefinition( d, *it_def ) )
-						{
-							// found the declaration, let's jump!
-							int line, column;
-							( *it_def ) ->getStartPosition( &line, &column );
-							KURL url;
-							url.setPath( (*it_def)->fileName() );
-							if ( scrollOnly ) {
-								KParts::ReadOnlyPart* part = partController()->partForURL( url );
-								uint currentLine = lastSyncedLine;
-								if( part ) {
-									uint col;
-									KTextEditor::ViewCursorInterface *iface = dynamic_cast<KTextEditor::ViewCursorInterface*>(part->widget());
-									if( iface )
-										iface->cursorPosition(  &currentLine, &col );
-								}
-								partController() ->scrollToLineColumn( url, line, -1, lastSyncedLine != currentLine || lastSyncedUrl != url );
-							} else if ( !splitHeaderSourceConfig()->splitEnabled() )
-								partController() ->editDocument( url, line );
-							else
-								partController() ->splitCurrentDocument( url, line );
-							lastSyncedLine = line;
-							lastSyncedUrl = url;
-							return ;
-						}
-					}
-				}
-			}
-		} else {
-			///No current function could be located, just open the other file
-		}
+		if ( switchHeaderImpl( m_activeFileName, currentline, column, candidate, scrollOnly ) )
+			return;
 	}
 
 	// last chance
@@ -1156,6 +1127,103 @@ void CppSupportPart::slotSwitchHeader( bool scrollOnly )
 		partController() ->splitCurrentDocument( url );
 }
 
+bool CppSupportPart::switchHeaderImpl( const QString& file, int line, int col, QString candidate, bool scrollOnly )
+{
+    bool handled = false;
+
+    if ( candidate == QString::null )
+        candidate = sourceOrHeaderCandidate( file );
+
+    if ( candidate != QString::null ) {
+
+        static KURL lastSyncedUrl;
+        static int lastSyncedLine = -1;
+
+        QValueList<FileDom> candidates;
+        if( codeModel()->hasFile( candidate ) ) candidates << codeModel()->fileByName( candidate );
+        FileDom activeFile = codeModel() ->fileByName( file );
+        candidates += activeFile->wholeGroup();
+
+        CodeModelUtils::CodeModelHelper h( codeModel(), activeFile );
+        FunctionDom d = h.functionAt( line, col );
+
+        if( d ) {
+            if( d->isFunctionDefinition() ) {
+                //Find the declaration in one of the other files
+                for( QValueList<FileDom>::iterator it = candidates.begin(); it != candidates.end(); ++it ) {
+                    FileDom source = *it;
+                    // found it. can we find a matching declaration?
+                    FunctionList functionList = CodeModelUtils::allFunctionsDetailed( source ).functionList;
+                    for ( FunctionList::ConstIterator it_decl = functionList.begin();
+                          it_decl != functionList.end(); ++it_decl )
+                    {
+                        if( (void*)&(*it_decl) == (void*)d.data() || (scrollOnly && (*it_decl)->fileName() == file ) ) continue;
+                        if ( CodeModelUtils::compareDeclarationToDefinition( *it_decl, (FunctionDefinitionModel*)(d.data()) ) )
+                        {
+                            // found the declaration, let's jump!
+                            ( *it_decl ) ->getStartPosition( &line, &col );
+                            KURL url;
+                            url.setPath( (*it_decl)->fileName() );
+                            if ( scrollOnly ) {
+                                KParts::ReadOnlyPart* part = partController()->partForURL( url );
+                                uint currentLine = lastSyncedLine;
+                                if( part ) {
+                                    KTextEditor::ViewCursorInterface *iface = dynamic_cast<KTextEditor::ViewCursorInterface*>(part->widget());
+                                    if( iface )
+                                        iface->cursorPosition( &currentLine, (uint*) &col );
+                                }
+                                partController() ->scrollToLineColumn( url, line, -1, lastSyncedLine != currentLine || lastSyncedUrl != url );
+                            } else if ( !splitHeaderSourceConfig()->splitEnabled() )
+                                partController() ->editDocument( url, line );
+                            else
+                                partController() ->splitCurrentDocument( url, line );
+                            lastSyncedLine = line;
+                            lastSyncedUrl = url;
+                            handled= true;
+                        }
+                    }
+                }
+            } else {
+                //Find the definition in one of the other files
+                for( QValueList<FileDom>::iterator it = candidates.begin(); it != candidates.end(); ++it ) {
+                    FileDom source = *it;
+                    FunctionDefinitionList functionDefList = CodeModelUtils::allFunctionDefinitionsDetailed( source ).functionList;
+                    for ( FunctionDefinitionList::ConstIterator it_def = functionDefList.begin();
+                          it_def != functionDefList.end(); ++it_def )
+                    {
+                        if( *it_def == d || (scrollOnly && (*it_def)->fileName() == file ) ) continue;
+                        if ( CodeModelUtils::compareDeclarationToDefinition( d, *it_def ) )
+                        {
+                            // found the declaration, let's jump!
+                            ( *it_def ) ->getStartPosition( &line, &col );
+                            KURL url;
+                            url.setPath( (*it_def)->fileName() );
+                            if ( scrollOnly ) {
+                                KParts::ReadOnlyPart* part = partController()->partForURL( url );
+                                uint currentLine = lastSyncedLine;
+                                if( part ) {
+                                    KTextEditor::ViewCursorInterface *iface = dynamic_cast<KTextEditor::ViewCursorInterface*>(part->widget());
+                                    if( iface )
+                                        iface->cursorPosition( &currentLine, (uint*) &col );
+                                }
+                                partController() ->scrollToLineColumn( url, line, -1, lastSyncedLine != currentLine || lastSyncedUrl != url );
+                            } else if ( !splitHeaderSourceConfig()->splitEnabled() )
+                                partController() ->editDocument( url, line );
+                            else
+                                partController() ->splitCurrentDocument( url, line );
+                            lastSyncedLine = line;
+                            lastSyncedUrl = url;
+                            handled= true;
+                        }
+                    }
+                }
+            }
+        }
+    }
+
+    return handled;
+}
+
 void CppSupportPart::slotGotoIncludeFile()
 {
 	if ( !m_contextFileName.isEmpty() )
@@ -1286,11 +1354,23 @@ bool CppSupportPart::parseProject( bool force )
 	kapp->setOverrideCursor( waitCursor );
 
 	_jd = new JobData;
-	_jd->file.setName( project() ->projectDirectory() + "/" + project() ->projectName() + ".pcs" );
+	if( QFileInfo( project() ->projectDirectory() + "/" + project()->projectName().lower() 
+				+ ".kdevelop.pcs" ).exists())
+	{
+		QDir d( project() ->projectDirectory());
+		d.rename(project() ->projectName().lower() + ".kdevelop.pcs", 
+					project() ->projectName() +".kdevelop.pcs");
+	}
+	_jd->file.setName( project() ->projectDirectory() + "/" + project()->projectName() 
+			+ ".kdevelop.pcs" );
+	
+	QString skip_file_name = project() ->projectDirectory() + "/" + 
+		project() ->projectName() + ".kdevelop.ignore_pcs";
+	QString skip_lower_file_name = project() ->projectDirectory() + "/" + 
+		project() ->projectName().lower() + ".kdevelop.ignore_pcs";
 
-	QString skip_file_name = project() ->projectDirectory() + "/" + project() ->projectName() + ".ignore_pcs";
-
-	if ( !force && !QFile::exists( skip_file_name ) && _jd->file.open( IO_ReadOnly ) )
+	if ( !force && !QFile::exists( skip_file_name ) && 
+			!QFile::exists( skip_lower_file_name ) && _jd->file.open( IO_ReadOnly ) )
 	{
 		_jd->stream.setDevice( &( _jd->file ) );
 
@@ -1431,8 +1511,13 @@ void CppSupportPart::slotParseFiles()
 				kapp->restoreOverrideCursor( );
 				emit updatedSourceInfo();
 				mainWindow( ) ->statusBar( ) ->message( i18n( "Done" ), 2000 );
-				QFile::remove
-					( project() ->projectDirectory() + "/" + project() ->projectName() + ".ignore_pcs" );
+				QFile::remove( project() ->projectDirectory() 
+						+ "/" + project() ->projectName() 
+						+ ".kdevelop.ignore_pcs" );
+				QFile::remove( project() ->projectDirectory() 
+						+ "/" + project() ->projectName().lower() 
+						+ ".kdevelop.ignore_pcs" );
+
 			}
 			else
 			{
@@ -1536,10 +1621,16 @@ void CppSupportPart::MakeMemberHelper( QString& text, int& atLine, int& atColumn
 	if ( !m_activeViewCursor || !m_valid )
 		return ;
 
+	atLine = -2;
+	atColumn = 0;
+	
+	QString implFile = findSourceFile();
+	
 	m_backgroundParser->lock();
 	TranslationUnitAST* translationUnit = *m_backgroundParser->translationUnit( m_activeFileName );
 	if ( translationUnit )
 	{
+		bool fail = false;
 		unsigned int line, column;
 		m_activeViewCursor->cursorPositionReal( &line, &column );
 
@@ -1552,14 +1643,21 @@ void CppSupportPart::MakeMemberHelper( QString& text, int& atLine, int& atColumn
 			currentNode = currentNode->parent();
 		}
 		SimpleDeclarationAST* decl = currentNode ? ( SimpleDeclarationAST* ) currentNode : 0;
-		if ( decl && decl->initDeclaratorList() && !declarator )
+		
+		if ( decl && decl->storageSpecifier() && decl->storageSpecifier()->text().contains("friend") )
+		{
+			kdDebug(9007) << "this is a friend declaration, don't create any definition" << endl;
+			fail = true;
+		}
+		
+		if ( !fail && decl && decl->initDeclaratorList() && !declarator )
 		{
 			InitDeclaratorAST * i = decl->initDeclaratorList() ->initDeclaratorList().at( 0 );
 			if ( i )
 				declarator = i->declarator();
 		}
 
-		if ( decl && declarator && declarator->parameterDeclarationClause() )
+		if ( !fail && decl && declarator && declarator->parameterDeclarationClause() )
 		{
 
 			QStringList scope;
@@ -1596,19 +1694,13 @@ void CppSupportPart::MakeMemberHelper( QString& text, int& atLine, int& atColumn
 			text += declStr + "\n{\n}";
 		}
 
-		m_backgroundParser->unlock();
-
-		QString implFile = findSourceFile();
-
-		m_backgroundParser->lock();
-		translationUnit = *m_backgroundParser->translationUnit( implFile );
-		if ( translationUnit )
-			translationUnit->getEndPosition( &atLine, &atColumn );
-		else
+		if ( !fail )
 		{
-			atLine = -2;
-			atColumn = 0;
+			translationUnit = *m_backgroundParser->translationUnit( implFile );
+			if ( translationUnit )
+				translationUnit->getEndPosition( &atLine, &atColumn );
 		}
+		
 		kdDebug() << "at line in mm: " << atLine << endl;
 	}
 	m_backgroundParser->unlock();
@@ -1759,12 +1851,7 @@ void CppSupportPart::setupCatalog( )
 	if ( pcsList.size() && pcsVersion() < KDEV_DB_VERSION )
 	{
 		QStringList l = pcsList + pcsIdxList;
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
 		int rtn = KMessageBox::questionYesNoList( 0, i18n( "Persistant class store will be disabled: you have a wrong version of pcs installed.\nRemove old pcs files?" ), l, i18n( "C++ Support" ), KStdGuiItem::del(), KStdGuiItem::cancel() );
-#else
-		int rtn = KMessageBox::questionYesNoList( 0, i18n( "Persistant class store will be disabled: you have a wrong version of pcs installed.\nRemove old pcs files?" ), l, i18n( "C++ Support" ), KGuiItem( i18n( "&Delete" ), "editdelete", i18n( "Delete item(s)" )), KStdGuiItem::cancel() );
-#endif
-
 		if ( rtn == KMessageBox::Yes )
 		{
 			QStringList::Iterator it = l.begin();
@@ -1965,7 +2052,8 @@ void CppSupportPart::saveProjectSourceInfo()
 	if ( !project() || fileList.isEmpty() )
 		return ;
 
-	QFile f( project() ->projectDirectory() + "/" + project() ->projectName() + ".pcs" );
+	QFile f( project() ->projectDirectory() + "/" 
+			+ project() ->projectName() + ".kdevelop.pcs" );
 	if ( !f.open( IO_WriteOnly ) )
 		return ;
 
@@ -2005,9 +2093,10 @@ void CppSupportPart::saveProjectSourceInfo()
 		stream.device() ->at( end );
 	}
 
-	QString skip_file_name = project() ->projectDirectory() + "/" + project() ->projectName() + ".ignore_pcs";
-	QFile::remove
-		( skip_file_name );
+	QFile::remove(  project() ->projectDirectory() + "/" 
+			+ project() ->projectName() + ".kdevelop.ignore_pcs" );
+	QFile::remove(  project() ->projectDirectory() + "/" 
+			+ project() ->projectName().lower() + ".kdevelop.ignore_pcs" );
 
 	m_backgroundParser->unlock();
 }
@@ -2148,6 +2237,9 @@ int CppSupportPart::parseFilesAndDependencies( QStringList files, bool backgroun
 
 		kdDebug() << "reparsing the following group: " << ":\n" << group.join("\n") << "\n\n";
 		if( background ) {
+
+			m_backgroundParser->lock();
+
 			if( !group.isEmpty() ) {
 				if( !parseFirst )
 					m_parseEmitWaiting.addGroup( group, silent ? ParseEmitWaiting::Silent : ParseEmitWaiting::None  );
@@ -2177,6 +2269,9 @@ int CppSupportPart::parseFilesAndDependencies( QStringList files, bool backgroun
 					backgroundParser()->addFile(*it);
 				}
 			}
+
+			m_backgroundParser->unlock();
+
 		} else {
 			for(QStringList::iterator it = group.begin(); it != group.end(); ++it) {
 				if( !silent && _jd ) //If this this file is not silent and thus not part of the initial parse, increase the background-count so the progress-bar does not get confused
@@ -2237,35 +2332,15 @@ void CppSupportPart::parseEmit( ParseEmitWaiting::Processed files ) {
 
 		QStringList l = files.res;
 
-		//QValueList<FileDom> fileBackups;
-
-		while(!l.isEmpty() )
-		{
-			if ( codeModel() ->hasFile( l.back() ) && m_backgroundParser->hasTranslationUnit( l.back() ) )
-			{
-				//fileBackups << codeModel()->fileByName( l.back() );
-				removeWithReferences( l.back() );
-
-				///update timestamps
-				  QString& fileName = l.back();
-
-				  QFileInfo fileInfo( fileName );
-				  QString path = URLUtil::canonicalPath( fileName );
-
-				  m_timestamp[ path ] = fileInfo.lastModified();
-			}
-
-			l.pop_back();
-		}
-
-		l = files.res;
-
 		///Since even normal typing may create problems, these must not break the group, so group everything together afterwards
 		int currentGroup = 0;
 
 		QMap<QString, bool> wholeResult;
 		QStringList missing;
 
+		bool updated = true; ///Could the current code-model be updated to reflect the changes?
+		QMap<QString, FileDom> newFiles;
+		
 		while(!l.isEmpty() ) {
 			QString fileName = l.front();
 
@@ -2277,9 +2352,25 @@ void CppSupportPart::parseEmit( ParseEmitWaiting::Processed files ) {
 				{
 					if ( true /*!hasErrors*/ )
 					{
+						FileDom oldFile = codeModel()->fileByName( fileName );
+						
 						StoreWalker walker( fileName, codeModel() );
+						walker.setOverrides( newFiles );
+						
 						walker.parseTranslationUnit( *ast );
-						codeModel() ->addFile( walker.file() );
+
+						if( oldFile ) {
+							newFiles[fileName] = walker.file();
+							
+							///update timestamps
+							QFileInfo fileInfo( fileName );
+							QString path = URLUtil::canonicalPath( fileName );
+
+							m_timestamp[ path ] = fileInfo.lastModified();
+						} else {
+							codeModel() ->addFile( walker.file() );
+						}
+						
 						if( walker.file() ) {
 							QStringList grp = walker.file()->wholeGroupStrings();
 							for( QStringList::const_iterator it = grp.begin(); it != grp.end(); ++it )
@@ -2307,11 +2398,35 @@ void CppSupportPart::parseEmit( ParseEmitWaiting::Processed files ) {
 			l.pop_front();
 		}
 
+		bool canUpdate = true;
+		for( QMap<QString, FileDom>::const_iterator it = newFiles.begin(); it != newFiles.end(); ++it ) {
+			FileDom oldFile = codeModel()->fileByName( it.key() );
+
+			if( !oldFile->canUpdate( *it ) ) {
+				canUpdate = false;
+				break;
+			}
+		}
+
+		if( canUpdate ) {
+			///Update the code-model
+			for( QMap<QString, FileDom>::const_iterator it = newFiles.begin(); it != newFiles.end(); ++it ) {
+				FileDom oldFile = codeModel()->fileByName( it.key() );
+				oldFile->update( *it );
+			}
+		} else {
+			///Remove the current files and replace them with the new ones
+			for( QMap<QString, FileDom>::const_iterator it = newFiles.begin(); it != newFiles.end(); ++it ) {
+				removeWithReferences( it.key() );
+				codeModel()->addFile( *it );
+			}
+		}
+		/*
 		///make the list unique
 
 		l.clear();
 		for( QMap<QString, bool>::const_iterator it = wholeResult.begin(); it != wholeResult.end(); ++it )
-			l << it.key();
+			l << it.key();*/
 
 		m_backgroundParser->unlock();
 
@@ -2325,10 +2440,21 @@ void CppSupportPart::parseEmit( ParseEmitWaiting::Processed files ) {
 			for( QStringList::iterator it = files.res.begin(); it != files.res.end(); ++it )
 				m_backgroundParser->removeFile( *it );
 		} else {
-			QStringList l = files.res;
-			while(!l.isEmpty() ) {
-				emit addedSourceInfo( l.front() );
-				l.pop_front();
+			if( !canUpdate ) {  ///If the current model could be updated, do not emit addedSourceInfo(..) and remove the units from the parser, because nobody will be using them
+				QStringList l = files.res;
+				while(!l.isEmpty() ) {
+					emit addedSourceInfo( l.front() );
+					l.pop_front();
+				}
+				
+				if( !files.hasFlag( ParseEmitWaiting::Silent ) )
+					emitFileParsed( files );
+			} else {
+				QStringList l = files.res;
+				while( !l.isEmpty() ) {
+					emit codeModelUpdated( l.front() );
+					l.pop_front();
+				}
 			}
 		}
 		kdDebug( 9007 ) << "files in code-model after parseEmit: " << codeModel()->fileList().count() << " before: " << oldFileCount << endl;
@@ -2459,10 +2585,11 @@ void CppSupportPart::slotCursorPositionChanged()
 		slotSwitchHeader( true );
 }
 
+/*
 void CppSupportPart::slotFunctionHint( )
 {
 	kdDebug( 9007 ) << "=======> compute current function definition" << endl;
-	m_functionHintTimer->stop();
+// 	m_functionHintTimer->stop();
 	if ( FunctionDefinitionDom fun = currentFunctionDefinition() )
 	{
 		QStringList scope = fun->scope();
@@ -2475,12 +2602,14 @@ void CppSupportPart::slotFunctionHint( )
 		mainWindow() ->statusBar() ->message( funName, 2000 );
 	}
 }
+*/
 
 void CppSupportPart::createIgnorePCSFile( )
 {
 	static QCString skip_me( "ignore me\n" );
 
-	QString skip_file_name = project() ->projectDirectory() + "/" + project() ->projectName() + ".ignore_pcs";
+	QString skip_file_name = project() ->projectDirectory() + "/" 
+		+ project() ->projectName() + ".kdevelop.ignore_pcs";
 	QFile skip_pcs_file( skip_file_name );
 	if ( skip_pcs_file.open( IO_WriteOnly ) )
 	{
@@ -2714,5 +2843,47 @@ void CppSupportPart::createAccessMethods( ClassDom theClass, VariableDom theVari
 	slotCreateAccessMethods();
 }
 
+void CppSupportPart::slotCursorMoved()
+{
+	m_cursorMovedTimer->start( 250, true );
+}
+
+void CppSupportPart::slotTextChanged()
+{
+	setTyping( true );	///@todo check if this is really needed
+
+	if ( m_backgroundParserConfig->useBackgroundParser() )
+	{
+		m_textChangedTimer->start( m_backgroundParserConfig->backgroudParseDelay(), true );
+	}
+}
+
+void CppSupportPart::slotParseCurrentFile()
+{
+ 	if( isValid() && !isQueued( m_activeFileName ) )
+	{
+		parseFileAndDependencies( m_activeFileName, true, true );
+	}
+}
+
+void CppSupportPart::updateBackgroundParserConfig()
+{
+	BackgroundParserConfig config;
+	config.readConfig();
+
+	if ( m_backgroundParserConfig->useProblemReporter() && !config.useProblemReporter() )
+	{
+		removeProblemReporter();
+	}
+	else if ( !m_backgroundParserConfig->useProblemReporter() && config.useProblemReporter() )
+	{
+		embedProblemReporter( true );
+	}
+
+	*m_backgroundParserConfig = config;
+}
+
 #include "cppsupportpart.moc"
 //kate: indent-mode csands; tab-width 4; space-indent off;
+
+
