@@ -49,6 +49,8 @@ class QTimer;
 class KListView;
 class Driver;
 class KPopupMenu;
+class BackgroundParserConfig;
+class KAction;
 
 
 namespace KParts
@@ -79,13 +81,14 @@ public:
 
 	QString specialHeaderName( bool local = false ) const;
 	void updateParserConfiguration();
-
+	void updateBackgroundParserConfig();
+	
 	// @fixme - isValid is used to avoid using the problem reporter
 	// when a project is first parsed. This because the problem reporter
 	// is currently a great slowdown for large projects (see bug #73671)
     ProblemReporter* problemReporter() const
 	{
-		return isValid() ? static_cast<ProblemReporter *>( m_problemReporter ) : 0;
+ 		return isValid() ? static_cast<ProblemReporter *>( m_problemReporter ) : 0;
 	}
 
     /** parses the file and all files that belong to it using the background-parser */
@@ -173,9 +176,12 @@ public:
 	void createAccessMethods( ClassDom theClass, VariableDom theVariable );
 
     bool isQueued( const QString& file ) const;
+    bool switchHeaderImpl( const QString& file, int line, int col, QString candidate = QString::null, bool scrollOnly = false );
 
 signals:
 	void fileParsed( const QString& fileName );
+    ///Emitted whenever a file was parsed, but the code-model could be updated(the file in the code-model did not have to be replaced)
+	void codeModelUpdated( const QString& fileName );
 	///Emitted whenever a translation-unit was parsed in the main thread
 	void synchronousParseReady( const QString& file, ParsedFilePointer unit );
     
@@ -214,7 +220,7 @@ private slots:
 	void slotMakeMember();
 	void slotExtractInterface();
 	void slotCursorPositionChanged();
-	void slotFunctionHint();
+// 	void slotFunctionHint();
 	void gotoLine( int line );
 	void gotoDeclarationLine( int line );
     void emitFileParsed( QStringList l );
@@ -223,6 +229,12 @@ private slots:
 	void slotCreateAccessMethods();
 	void slotDeleteParserStore();
     void slotSaveMemory();
+	void slotTextChanged();
+	void slotCursorMoved();
+	void slotParseCurrentFile();
+	void embedProblemReporter( bool force = false );
+	void removeProblemReporter();
+	
 
 	void slotNeedTextHint( int, int, QString& );
 
@@ -297,7 +309,8 @@ private:
     CppSplitHeaderSourceConfig* m_pSplitHeaderSourceConfig;
 
 	CreateGetterSetterConfiguration* m_pCreateGetterSetterConfiguration;
-	class KAction* m_createGetterSetterAction;
+	KAction * m_createGetterSetterAction;
+	KAction * m_switchHeaderSourceAction;
 	
 	QtBuildConfig* m_qtBuildConfig;
 
@@ -338,9 +351,11 @@ private:
 
 	QGuardedPtr<KPopupMenu> m_navigationMenu;
 
-	QTimer* m_functionHintTimer;
-	QTimer* m_deleteParserStoreTimer;
+// 	QTimer* m_functionHintTimer;
+// 	QTimer* m_deleteParserStoreTimer;
 	QTimer* m_saveMemoryTimer;
+	QTimer * m_textChangedTimer;
+	QTimer * m_cursorMovedTimer;
     
     class ParseEmitWaiting {
     public:
@@ -425,9 +440,15 @@ private:
 			    return flag & HadQueueProblem;
 		    }
 
+		    bool hasFlag( Flags f ) const {
+			    return f & flag;
+		    }
+		    // surely a copy paste implementation?
+/*		    
     	    bool hasFlag( Flags flag ) const {
         	    return flag & HadQueueProblem;
     	    }
+*/
 	    };
 
 
@@ -485,6 +506,8 @@ private slots:
 	void parseEmit( ParseEmitWaiting::Processed files );
 private:
 	
+	BackgroundParserConfig * m_backgroundParserConfig;
+	
 	static QStringList m_sourceMimeTypes;
 	static QStringList m_headerMimeTypes;
 
