@@ -61,8 +61,8 @@ Dbg_PS_Dialog::Dbg_PS_Dialog(QWidget *parent, const char *name)
     pids_->addColumn("PID");
     pids_->addColumn("TTY");
     pids_->addColumn("STAT");
-    pids_->addColumn("COMMAND");
     pids_->addColumn("TIME");
+    pids_->addColumn("COMMAND");
 
 
     QBoxLayout *topLayout = new QVBoxLayout(this, 5);
@@ -74,15 +74,9 @@ Dbg_PS_Dialog::Dbg_PS_Dialog(QWidget *parent, const char *name)
     pids_->setFont(KGlobalSettings::fixedFont());
 
     KButtonBox *buttonbox = new KButtonBox(this, Qt::Horizontal);
-#if KDE_IS_VERSION( 3, 2, 90 )
     buttonbox->addStretch();
     QPushButton *ok       = buttonbox->addButton(KStdGuiItem::ok());
     QPushButton *cancel   = buttonbox->addButton(KStdGuiItem::cancel());
-#else
-    buttonbox->addStretch();
-    QPushButton *ok       = buttonbox->addButton(i18n("OK"));
-    QPushButton *cancel   = buttonbox->addButton(i18n("Cancel"));
-#endif
     buttonbox->layout();
     topLayout->addWidget(buttonbox);
 
