@@ -119,7 +119,7 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
                                          0, "variablewidget");
     mainWindow()->embedSelectView(variableWidget, i18n("Variables"),
                                   i18n("Debugger variable-view"));
-
+    mainWindow()->setViewAvailable(variableWidget, false);
 
     framestackWidget = new FramestackWidget( controller, 0, "framestackWidget" );
     framestackWidget->setEnabled(false);
@@ -384,15 +384,7 @@ void DebuggerPart::slotDCOPApplicationRegistered(const QCString& appId)
         QByteArray answer;
         QCString replyType;
 
-#if defined(KDE_MAKE_VERSION)
-# if KDE_VERSION >= KDE_MAKE_VERSION(3,1,90)
         kapp->dcopClient()->call(appId, "krashinfo", "appName()", QByteArray(), replyType, answer, true, 5000);
-# else
-        kapp->dcopClient()->call(appId, "krashinfo", "appName()", QByteArray(), replyType, answer, true);
-# endif
-#else
-        kapp->dcopClient()->call(appId, "krashinfo", "appName()", QByteArray(), replyType, answer, true);
-#endif
 
         QDataStream d(answer, IO_ReadOnly);
         QCString appName;
@@ -410,15 +402,7 @@ ASYNC DebuggerPart::slotDebugExternalProcess()
     QByteArray answer;
     QCString replyType;
 
-#if defined(KDE_MAKE_VERSION)
-# if KDE_VERSION >= KDE_MAKE_VERSION(3,1,90)
     kapp->dcopClient()->call(kapp->dcopClient()->senderId(), "krashinfo", "pid()", QByteArray(), replyType, answer, true, 5000);
-# else
-    kapp->dcopClient()->call(kapp->dcopClient()->senderId(), "krashinfo", "pid()", QByteArray(), replyType, answer, true);
-# endif
-#else
-    kapp->dcopClient()->call(kapp->dcopClient()->senderId(), "krashinfo", "pid()", QByteArray(), replyType, answer, true);
-#endif
 
     QDataStream d(answer, IO_ReadOnly);
     int pid;
@@ -651,23 +635,26 @@ bool DebuggerPart::startDebugger()
         run_envvars   = project()->runEnvironmentVars();
         run_directory = project()->runDirectory();
         program       = project()->mainProgram();
-        run_arguments = DomUtil::readEntry(*projectDom(), "/kdevdebugger/general/programargs");
+        run_arguments = project()->debugArguments();
     }
 
     QString shell = DomUtil::readEntry(*projectDom(), "/kdevdebugger/general/dbgshell");
     if( !shell.isEmpty() )
     {
-        QFileInfo info( shell );
+        shell = shell.simplifyWhiteSpace();
+        QString shell_without_args = QStringList::split(QChar(' '), shell ).first();
+
+        QFileInfo info( shell_without_args );
         if( info.isRelative() )
         {
-            shell = build_dir + "/" + shell;
-            info.setFile( shell );
+            shell_without_args = build_dir + "/" + shell_without_args;
+            info.setFile( shell_without_args );
         }
         if( !info.exists() )
         {
             KMessageBox::error(
                 mainWindow()->main(),
-                i18n("Could not locate the debugging shell '%1'.").arg( shell ),
+                i18n("Could not locate the debugging shell '%1'.").arg( shell_without_args ),
                 i18n("Debugging Shell Not Found") );
             return false;
         }
@@ -695,6 +682,7 @@ bool DebuggerPart::startDebugger()
         mainWindow()->setViewAvailable(framestackWidget, true);
         mainWindow()->setViewAvailable(disassembleWidget, true);
         mainWindow()->setViewAvailable(gdbOutputWidget, true);
+        mainWindow()->setViewAvailable(variableWidget, true);
 
         framestackWidget->setEnabled(true);
         disassembleWidget->setEnabled(true);
@@ -739,7 +727,7 @@ void DebuggerPart::slotStopDebugger()
     gdbOutputWidget->setEnabled(false);
 
 
-//    mainWindow()->setViewAvailable(variableWidget, false);
+    mainWindow()->setViewAvailable(variableWidget, false);
     mainWindow()->setViewAvailable(framestackWidget, false);
     mainWindow()->setViewAvailable(disassembleWidget, false);
     mainWindow()->setViewAvailable(gdbOutputWidget, false);
@@ -1102,20 +1090,6 @@ void DebuggerPart::slotStatus(const QString &msg, int state)
         stateIndicator = " ";
         stateIndicatorFull = "Debugger not started";
         stateChanged( QString("stopped") );
-
-        // If the view is undocked, don't hide it. User has explicitly
-        // undocked it and moved into a convenient position. Don't
-        // force him to undock the widget and move it again next
-        // time the debugger starts.
-        bool undocked = false;
-
-        if (KDockWidget* dockWidget =
-            static_cast<KDockWidget*>(
-                variableWidget->parentWidget()->qt_cast("KDockWidget")))
-        {
-            if (dockWidget->currentDockPosition() == KDockWidget::DockDesktop)
-                undocked = true;
-        }
     }
     else if (state & s_dbgBusy)
     {
@@ -1143,6 +1117,7 @@ void DebuggerPart::slotStatus(const QString &msg, int state)
         if (justRestarted_)
         {
             justRestarted_ = false;
+            mainWindow()->setViewAvailable(variableWidget, true);
             mainWindow()->raiseView(variableWidget);
         }
     }
