@@ -31,6 +31,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kprocess.h>
+#include <kwin.h>
 
 #include <qdatetime.h>
 #include <qfileinfo.h>
@@ -43,6 +44,7 @@
 #include <iostream>
 #include <ctype.h>
 #include <stdlib.h>
+#include <assert.h>
 #include <typeinfo>
 using namespace std;
 
@@ -134,7 +136,6 @@ GDBController::GDBController(QDomDocument &projectDom)
         viewedThread_(-1),
         holdingZone_(),
         currentCmd_(0),
-        currentMemoryCallback_(0),
         tty_(0),
         badCore_(QString()),
         state_(s_dbgNotStarted|s_appNotStarted),
@@ -198,7 +199,7 @@ void GDBController::configure()
     config_outputRadix_   = DomUtil::readIntEntry(dom, "/kdevdebugger/display/outputradix", 10);
     varTree_->setRadix(config_outputRadix_);
 #endif
-    
+
 
     if (( old_displayStatic             != config_displayStaticMembers_   ||
             old_asmDemangle             != config_asmDemangle_            ||
@@ -216,49 +217,35 @@ void GDBController::configure()
         if (old_displayStatic != config_displayStaticMembers_)
         {
             if (config_displayStaticMembers_)
-                queueCmd(new GDBCommand("set print static-members on", NOTRUNCMD,
-                                        NOTINFOCMD));
+                queueCmd(new GDBCommand("set print static-members on"));
             else
-                queueCmd(new GDBCommand("set print static-members off", NOTRUNCMD,
-                                        NOTINFOCMD));
+                queueCmd(new GDBCommand("set print static-members off"));
         }
         if (old_asmDemangle != config_asmDemangle_)
         {
             if (config_asmDemangle_)
-                queueCmd(new GDBCommand("set print asm-demangle on", NOTRUNCMD,
-                                        NOTINFOCMD));
+                queueCmd(new GDBCommand("set print asm-demangle on"));
             else
-                queueCmd(new GDBCommand("set print asm-demangle off", NOTRUNCMD,
-                                        NOTINFOCMD));
+                queueCmd(new GDBCommand("set print asm-demangle off"));
         }
 
         // Disabled for MI port.
-#if 0
-        if (old_breakOnLoadingLibrary_ != config_breakOnLoadingLibrary_)
-        {
-            if (config_breakOnLoadingLibrary_)
-                queueCmd(new GDBCommand("set stop-on 1", NOTRUNCMD, NOTINFOCMD));
-            else
-                queueCmd(new GDBCommand("set stop-on 0", NOTRUNCMD, NOTINFOCMD));
-        }
-#endif
-
         if (old_outputRadix != config_outputRadix_)
         {
             queueCmd(new GDBCommand(QCString().sprintf("set output-radix %d",
-                                config_outputRadix_), NOTRUNCMD, NOTINFOCMD));
+                                config_outputRadix_)));
 
             // FIXME: should do this in variable widget anyway.
             // After changing output radix, need to refresh variables view.
             raiseEvent(program_state_changed);
 
         }
-        
+
         if (!config_configGdbScript_.isEmpty())
-          queueCmd(new GDBCommand("source " + config_configGdbScript_, NOTINFOCMD, 0));
+          queueCmd(new GDBCommand("source " + config_configGdbScript_));
 
         if (restart)
-            queueCmd(new GDBCommand("-exec-continue", NOTINFOCMD, 0));
+            queueCmd(new GDBCommand("-exec-continue"));
     }
 }
 
@@ -269,9 +256,19 @@ void GDBController::addCommand(GDBCommand* cmd)
     queueCmd(cmd);
 }
 
+void GDBController::addCommand(const QString& str)
+{
+    queueCmd(new GDBCommand(str));
+}
+
 void GDBController::addCommandToFront(GDBCommand* cmd)
 {
-    queueCmd(cmd, true);
+    queueCmd(cmd, queue_at_front);
+}
+
+void GDBController::addCommandBeforeRun(GDBCommand* cmd)
+{
+    queueCmd(cmd, queue_before_run);
 }
 
 int  GDBController::currentThread() const
@@ -290,27 +287,36 @@ int GDBController::currentFrame() const
 // information requests become redundent and must be removed.
 // We also try and run whatever command happens to be at the head of
 // the queue.
-void GDBController::queueCmd(GDBCommand *cmd, bool executeNext)
+void GDBController::queueCmd(GDBCommand *cmd, enum queue_where queue_where)
 {
     if (stateIsOn(s_dbgNotStarted))
     {
         KMessageBox::error(
-            0, 
+            0,
             i18n("<b>Gdb command sent when debugger is not running</b><br>"
-            "The command was:<br> %1").arg(cmd->rawDbgCommand()),
+            "The command was:<br> %1").arg(cmd->initialString()),
             i18n("Internal error"));
-        return;                    
+        return;
     }
 
     if (stateReloadInProgress_)
         stateReloadingCommands_.insert(cmd);
 
-    if (executeNext)
+    if (queue_where == queue_at_front)
         cmdList_.insert(0, cmd);
-    else
+    else if (queue_where == queue_at_end)
         cmdList_.append (cmd);
+    else if (queue_where == queue_before_run)
+    {
+        unsigned i;
+        for (i = 0; i < cmdList_.count(); ++i)
+            if (cmdList_.at(i)->isRun())
+                break;
 
-    kdDebug(9012) << "QUEUE: " << cmd->rawDbgCommand() 
+        cmdList_.insert(i, cmd);
+    }
+
+    kdDebug(9012) << "QUEUE: " << cmd->initialString()
                   << (stateReloadInProgress_ ? " (state reloading)\n" : "\n");
 
     setStateOn(s_dbgBusy);
@@ -355,7 +361,7 @@ void GDBController::executeCmd()
     if (length == 0)
     {
         // The command might decide it's no longer necessary to send
-        // it. 
+        // it.
         if (SentinelCommand* sc = dynamic_cast<SentinelCommand*>(currentCmd_))
         {
             kdDebug(9012) << "SEND: sentinel command, not sending\n";
@@ -363,7 +369,7 @@ void GDBController::executeCmd()
         }
         else
         {
-            kdDebug(9012) << "SEND: command " << currentCmd_->rawDbgCommand()
+            kdDebug(9012) << "SEND: command " << currentCmd_->initialString()
                           << " changed its mind, not sending\n";
         }
 
@@ -372,7 +378,7 @@ void GDBController::executeCmd()
         commandDone();
         return;
     }
-    else 
+    else
     {
         if (commandText[length-1] != '\n')
         {
@@ -398,7 +404,7 @@ void GDBController::executeCmd()
     prettyCmd.replace( QRegExp("set prompt \032.\n"), "" );
     prettyCmd = "(gdb) " + prettyCmd;
 
-    if (currentCmd_->typeMatch(USERCMD))
+    if (currentCmd_->isUserCommand())
         emit gdbUserCommandStdout( prettyCmd.latin1() );
     else
         emit gdbInternalCommandStdout( prettyCmd.latin1() );
@@ -426,6 +432,9 @@ void GDBController::pauseApp()
 {
     setStateOn(s_explicitBreakInto);
 
+    /* FIXME: need to decide if we really
+       need this, and the consistenly mark
+       info commands as such.
     int i = cmdList_.count();
     while (i)
     {
@@ -434,6 +443,7 @@ void GDBController::pauseApp()
         if (cmd->isAnInfoCmd())
             delete cmdList_.take(i);
     }
+    */
 
     if (dbgProcess_)
         dbgProcess_->kill(SIGINT);
@@ -460,7 +470,7 @@ void GDBController::actOnProgramPauseMI(const GDBMI::ResultRecord& r)
     if (shared_library_load)
     {
         raiseEvent(shared_library_loaded);
-        queueCmd(new GDBCommand("-exec-continue", RUNCMD, NOTINFOCMD));        
+        queueCmd(new GDBCommand("-exec-continue"));
         return;
     }
 
@@ -470,7 +480,7 @@ void GDBController::actOnProgramPauseMI(const GDBMI::ResultRecord& r)
         // caller. Show message box in the caller, not here.
         // FIXME: remove this 'bla-bla-bla'.
         KMessageBox::detailedSorry(
-            0, 
+            0,
             i18n("<b>Invalid gdb reply</b>"
                  "<p>The 'stopped' packet does not include the 'reason' field'."),
             i18n("The gdb reply is: bla-bla-bla"),
@@ -506,8 +516,7 @@ void GDBController::actOnProgramPauseMI(const GDBMI::ResultRecord& r)
         // watchpoinst on program exit is the right thing to
         // do.
 
-        queueCmd(new GDBCommand("-exec-continue",
-                               RUNCMD, NOTINFOCMD));
+        queueCmd(new GDBCommand("-exec-continue"));
 
         state_reload_needed = false;
         return;
@@ -532,7 +541,7 @@ void GDBController::actOnProgramPauseMI(const GDBMI::ResultRecord& r)
 
             setStateOff(s_explicitBreakInto);
             emit dbgStatus("Application interrupted", state_);
-            // Will show the source line in the code 
+            // Will show the source line in the code
             // handling non-special stop kinds, below.
         }
 
@@ -543,10 +552,10 @@ void GDBController::actOnProgramPauseMI(const GDBMI::ResultRecord& r)
             // program has a signal that's caused the prog to stop.
             // Continuing from SIG FPE/SEGV will cause a "Cannot ..." and
             // that'll end the program.
-            KMessageBox::information(0, 
+            KMessageBox::information(0,
                                      i18n("Program received signal %1 (%2)")
                                      .arg(name).arg(user_name),
-                                     i18n("Received signal"));   
+                                     i18n("Received signal"));
         }
     }
 
@@ -556,7 +565,7 @@ void GDBController::actOnProgramPauseMI(const GDBMI::ResultRecord& r)
         emit breakpointHit(id);
     }
 
-    
+
 }
 
 
@@ -570,7 +579,7 @@ void GDBController::reloadProgramState()
     // The command has a bug that makes it always returns some file/line,
     // even if we're not in one.
     //
-    // FIXME: For gdb 6.4, should not send extra commands. 
+    // FIXME: For gdb 6.4, should not send extra commands.
     // That's for later, so that I verify that this three-command
     // approach works fine.
     if (r.hasField("frame") && r["frame"].hasField("line"))
@@ -584,7 +593,7 @@ void GDBController::reloadProgramState()
     }
 
     emit dbgStatus ("", state_);
-    
+
     // We're always at frame zero when the program stops
     // and we must reset the active flag
     if (r.hasField("thread-id"))
@@ -592,7 +601,7 @@ void GDBController::reloadProgramState()
     else
         viewedThread_ = -1;
     currentFrame_ = 0;
-    
+
     raiseEvent(program_state_changed);
     state_reload_needed = false;
 }
@@ -621,7 +630,7 @@ void GDBController::programNoApp(const QString &msg, bool msgBox)
     // output, so "exited" message from gdb might have arrived before
     // last application output. Get this last bit.
 
-    // Note: this method can be called when we open an invalid 
+    // Note: this method can be called when we open an invalid
     // core file. In that case, tty_ won't be set.
     if (tty_)
         tty_->readRemaining();
@@ -671,7 +680,7 @@ void GDBController::parseCliLine(const QString& line)
 #endif
 
 #if 0
-    
+
     /// @todo - Only do this at start up
     if (
         strstr(buf, "not in executable format:")                ||
@@ -699,22 +708,22 @@ void GDBController::handleMiFileListExecSourceFile(const GDBMI::ResultRecord& r)
         // to the caller, who knows the gdb output.
 #if 0
         KMessageBox::error(
-            0, 
+            0,
             i18n("Invalid gdb reply\n"
                  "Command was: %1\n"
                  "Response is: %2\n"
                  "Invalid response kind: \"%3\"")
             .arg(currentCmd_->rawDbgCommand())
             .arg(buf)
-            .arg(r.reason), 
+            .arg(r.reason),
             i18n("Invalid gdb reply"));
 #endif
     }
-    
+
     QString fullname = "";
     if (r.hasField("fullname"))
         fullname = r["fullname"].literal();
-    
+
     showStepInSource(fullname,
                      r["line"].literal().toInt(),
                      (*last_stop_result)["frame"]["addr"].literal());
@@ -722,7 +731,7 @@ void GDBController::handleMiFileListExecSourceFile(const GDBMI::ResultRecord& r)
     /* Watchpoint hit is announced only after we've highlighted
        the current line. */
     maybeAnnounceWatchpointHit();
- 
+
     last_stop_result.reset();
 }
 
@@ -733,17 +742,17 @@ void GDBController::maybeAnnounceWatchpointHit()
     if ((*last_stop_result).hasField("reason"))
     {
         QString last_stop_reason = (*last_stop_result)["reason"].literal();
-        
+
         if (last_stop_reason == "watchpoint-trigger")
         {
             emit watchpointHit((*last_stop_result)["wpt"]["number"]
                                .literal().toInt(),
                                (*last_stop_result)["value"]["old"].literal(),
                                (*last_stop_result)["value"]["new"].literal());
-        }    
+        }
         else if (last_stop_reason == "read-watchpoint-trigger")
         {
-            emit dbgStatus ("Read watchpoint triggered", state_);        
+            emit dbgStatus ("Read watchpoint triggered", state_);
         }
     }
 }
@@ -763,7 +772,7 @@ void GDBController::handleMiFrameSwitch(const GDBMI::ResultRecord& r)
     int line = -1;
     if (frame.hasField("line"))
         line = frame["line"].literal().toInt();
-                
+
     showStepInSource(file,
                      line,
                      frame["addr"].literal());
@@ -810,11 +819,11 @@ bool GDBController::start(const QString& shell, const DomUtil::PairList& run_env
 
     if (!shell.isEmpty())
     {
-        *dbgProcess_ << "/bin/sh" << "-c" << shell + " " + gdb + 
+        *dbgProcess_ << "/bin/sh" << "-c" << shell + " " + gdb +
                       + " " + application + " --interpreter=mi2 -quiet";
         emit gdbUserCommandStdout(
             QString( "/bin/sh -c " + shell + " " + gdb
-                     + " " + application 
+                     + " " + application
                      + " --interpreter=mi2 -quiet" ).latin1());
     }
     else
@@ -830,7 +839,7 @@ bool GDBController::start(const QString& shell, const DomUtil::PairList& run_env
                              KProcess::Communication(KProcess::All)))
     {
         KMessageBox::error(
-            0, 
+            0,
             i18n("<b>Could not start debugger.</b>"
                  "<p>Could not run '%1'. "
                  "Make sure that the path name is specified correctly."
@@ -853,14 +862,13 @@ bool GDBController::start(const QString& shell, const DomUtil::PairList& run_env
     // queueCmd(new GDBCommand("set confirm off", NOTRUNCMD, NOTINFOCMD));
 
     if (config_displayStaticMembers_)
-        queueCmd(new GDBCommand("set print static-members on", NOTRUNCMD,
-                                    NOTINFOCMD));
+        queueCmd(new GDBCommand("set print static-members on"));
     else
-        queueCmd(new GDBCommand("set print static-members off", NOTRUNCMD, NOTINFOCMD));
+        queueCmd(new GDBCommand("set print static-members off"));
 
     // This makes gdb pump a variable out on one line.
-    queueCmd(new GDBCommand("set width 0", NOTRUNCMD, NOTINFOCMD));
-    queueCmd(new GDBCommand("set height 0", NOTRUNCMD, NOTINFOCMD));
+    queueCmd(new GDBCommand("set width 0"));
+    queueCmd(new GDBCommand("set height 0"));
 
     // Get gdb to notify us of shared library events. This allows us to
     // set breakpoints in shared libraries that are not loaded yet. On each
@@ -871,36 +879,32 @@ bool GDBController::start(const QString& shell, const DomUtil::PairList& run_env
     // - This is broken for MI -break-insert command (the breakpoint is
     //   not inserted at all, and no error is produced)
     // - MI does not contains notification that pending breakpoint is resolved.
-    queueCmd(new GDBCommand("set stop-on-solib-events 1", 
-                            NOTRUNCMD, NOTINFOCMD));
+    queueCmd(new GDBCommand("set stop-on-solib-events 1"));
 
 
-    queueCmd(new GDBCommand("handle SIG32 pass nostop noprint", NOTRUNCMD,
-                            NOTINFOCMD));
-    queueCmd(new GDBCommand("handle SIG41 pass nostop noprint", NOTRUNCMD,
-                            NOTINFOCMD));
-    queueCmd(new GDBCommand("handle SIG42 pass nostop noprint", NOTRUNCMD,
-                            NOTINFOCMD));
-    queueCmd(new GDBCommand("handle SIG43 pass nostop noprint", NOTRUNCMD,
-                            NOTINFOCMD));
+    queueCmd(new GDBCommand("handle SIG32 pass nostop noprint"));
+    queueCmd(new GDBCommand("handle SIG41 pass nostop noprint"));
+    queueCmd(new GDBCommand("handle SIG42 pass nostop noprint"));
+    queueCmd(new GDBCommand("handle SIG43 pass nostop noprint"));
 
     // Print some nicer names in disassembly output. Although for an assembler
     // person this may actually be wrong and the mangled name could be better.
     if (config_asmDemangle_)
-        queueCmd(new GDBCommand("set print asm-demangle on", NOTRUNCMD, NOTINFOCMD));
+        queueCmd(new GDBCommand("set print asm-demangle on"));
     else
-        queueCmd(new GDBCommand("set print asm-demangle off", NOTRUNCMD, NOTINFOCMD));
+        queueCmd(new GDBCommand("set print asm-demangle off"));
 
     // make sure output radix is always set to users view.
-    queueCmd(new GDBCommand(QCString().sprintf("set output-radix %d",  config_outputRadix_), NOTRUNCMD, NOTINFOCMD));
-       
+    queueCmd(new GDBCommand(QCString().sprintf("set output-radix %d",  config_outputRadix_)));
+
     // Change the "Working directory" to the correct one
     QCString tmp( "cd " + QFile::encodeName( run_directory ));
-    queueCmd(new GDBCommand(tmp, NOTRUNCMD, NOTINFOCMD));
+    queueCmd(new GDBCommand(tmp));
 
     // Set the run arguments
     if (!run_arguments.isEmpty())
-        queueCmd(new GDBCommand(QCString("set args ") + run_arguments.latin1(), NOTRUNCMD, NOTINFOCMD));
+        queueCmd(
+            new GDBCommand(QCString("set args ") + run_arguments.local8Bit()));
 
     // Get the run environment variables pairs into the environstr string
     // in the form of: "ENV_VARIABLE=ENV_VALUE" and send to gdb using the
@@ -915,7 +919,7 @@ bool GDBController::start(const QString& shell, const DomUtil::PairList& run_env
         environstr += (*it).first;
         environstr += "=";
         environstr += (*it).second;
-        queueCmd(new GDBCommand(environstr.latin1(), NOTRUNCMD, NOTINFOCMD));
+        queueCmd(new GDBCommand(environstr.latin1()));
     }
 
     // Needed so that breakpoint widget has a chance to insert breakpoints.
@@ -923,7 +927,7 @@ bool GDBController::start(const QString& shell, const DomUtil::PairList& run_env
     setStateOn(s_dbgBusy);
     raiseEvent(debugger_ready);
     raiseEvent(connected_to_program);
-   
+
     // Now gdb has been started and the application has been loaded,
     // BUT the app hasn't been started yet! A run command is about to be issued
     // by whoever is controlling us. Or we might be asked to load a core, or
@@ -1010,7 +1014,7 @@ void GDBController::slotStopDebugger()
     // previously issued command that crashed gdb (so there's no end marker)
     // If we don't clear this, then after restart, we'll be trying to search
     // for the end marker of the command issued in previous gdb session,
-    // and never succeed. 
+    // and never succeed.
     gdbOutput_ = "";
 
     setState(s_dbgNotStarted | s_appNotStarted);
@@ -1026,9 +1030,8 @@ void GDBController::slotCoreFile(const QString &coreFile)
     setStateOff(s_programExited|s_appNotStarted);
     setStateOn(s_core);
 
-    queueCmd(new GDBCommand(QCString("core ") + coreFile.latin1(), 
-                                NOTINFOCMD, 0));
-   
+    queueCmd(new GDBCommand(QCString("core ") + coreFile.latin1()));
+
     raiseEvent(connected_to_program);
     raiseEvent(program_state_changed);
 }
@@ -1046,18 +1049,18 @@ void GDBController::slotAttachTo(int pid)
     // We can't omit application name from gdb invocation
     // because for libtool binaries, we have no way to guess
     // real binary name.
-    queueCmd(new GDBCommand(QString("file"), NOTINFOCMD, 0));
+    queueCmd(new GDBCommand(QString("file")));
 
     // The MI interface does not implements -target-attach yet,
     // and we don't recognize whatever gibberish 'attach' pours out, so...
     queueCmd(new GDBCommand(
-        QCString().sprintf("attach %d", pid), NOTINFOCMD, 0));
+        QCString().sprintf("attach %d", pid)));
 
     raiseEvent(connected_to_program);
-    
-    // ...emit a separate MI command to step one instruction more. We'll 
+
+    // ...emit a separate MI command to step one instruction more. We'll
     // notice the '*stopped' response from it and proceed as usual.
-    queueCmd(new GDBCommand("-exec-step-instruction", NOTINFOCMD, 0));
+    queueCmd(new GDBCommand("-exec-step-instruction"));
 }
 
 // **************************************************************************
@@ -1069,14 +1072,14 @@ void GDBController::slotRun()
 
     if (stateIsOn(s_appNotStarted)) {
 
-        delete tty_;        
+        delete tty_;
         tty_ = new STTY(config_dbgTerminal_, Settings::terminalEmulatorName( *kapp->config() ));
         if (!config_dbgTerminal_)
         {
             connect( tty_, SIGNAL(OutOutput(const char*)), SIGNAL(ttyStdout(const char*)) );
             connect( tty_, SIGNAL(ErrOutput(const char*)), SIGNAL(ttyStderr(const char*)) );
         }
-        
+
         QString tty(tty_->getSlave());
         if (tty.isEmpty())
         {
@@ -1085,13 +1088,13 @@ void GDBController::slotRun()
                                        "As root you may need to \"chmod ug+rw\" tty* and pty* devices "
                                        "and/or add the user to the tty group using "
                                        "\"usermod -G tty username\"."));
-            
+
             delete tty_;
             tty_ = 0;
             return;
         }
-        
-        queueCmd(new GDBCommand(QCString("tty ")+tty.latin1(), NOTINFOCMD));        
+
+        queueCmd(new GDBCommand(QCString("tty ")+tty.latin1()));
 
         if (!config_runShellScript_.isEmpty()) {
             // Special for remote debug...
@@ -1114,19 +1117,18 @@ void GDBController::slotRun()
             // Future: the shell script should be able to pass info (like pid)
             // to the gdb script...
 
-            queueCmd(new GDBCommand("source " + config_runGdbScript_,
-                                    NOTINFOCMD, 0));
+            queueCmd(new GDBCommand("source " + config_runGdbScript_));
 
             // Note: script could contain "run" or "continue"
         }
         else {
 
             QFileInfo app(application_);
-    
+
             if (!app.exists())
             {
                 KMessageBox::error(
-                    0, 
+                    0,
                     i18n("<b>Application does not exist</b>"
                          "<p>The application you're trying to debug,<br>"
                          "    %1\n"
@@ -1138,13 +1140,13 @@ void GDBController::slotRun()
                 // FIXME: after this, KDevelop will still show that debugger
                 // is running, because DebuggerPart::slotStopDebugger won't be
                 // called, and core()->running(this, false) won't be called too.
-                slotStopDebugger();                
+                slotStopDebugger();
                 return;
             }
             if (!app.isExecutable())
             {
                 KMessageBox::error(
-                    0, 
+                    0,
                     i18n("<b>Could not run application '%1'.</b>"
                          "<p>The application does not have the executable bit set. "
                          "Try rebuilding the project, or change permissions "
@@ -1155,14 +1157,14 @@ void GDBController::slotRun()
             }
             else
             {
-                queueCmd(new GDBCommand("-exec-run", NOTINFOCMD, 0));
+                queueCmd(new GDBCommand("-exec-run"));
             }
         }
     }
     else {
         removeStateReloadingCommands();
 
-        queueCmd(new GDBCommand("-exec-continue", NOTINFOCMD, 0));
+        queueCmd(new GDBCommand("-exec-continue"));
     }
     setStateOff(s_appNotStarted|s_programExited);
 }
@@ -1178,7 +1180,7 @@ void GDBController::slotKill()
         pauseApp();
     }
 
-    queueCmd(new GDBCommand("kill", NOTINFOCMD, 0));
+    queueCmd(new GDBCommand("kill"));
 
     setStateOn(s_appNotStarted);
 }
@@ -1193,12 +1195,12 @@ void GDBController::slotRunUntil(const QString &fileName, int lineNum)
     removeStateReloadingCommands();
 
     if (fileName.isEmpty())
-        queueCmd(new GDBCommand( QCString().sprintf("-exec-until %d", lineNum),
-                                NOTINFOCMD, 0));
+        queueCmd(new GDBCommand(
+                     QCString().sprintf("-exec-until %d", lineNum)));
     else
         queueCmd(new GDBCommand(
-                QCString().sprintf("-exec-until %s:%d", fileName.latin1(), lineNum),
-                                NOTINFOCMD, 0));
+                QCString().
+                sprintf("-exec-until %s:%d", fileName.latin1(), lineNum)));
 }
 
 // **************************************************************************
@@ -1209,8 +1211,8 @@ void GDBController::slotJumpTo(const QString &fileName, int lineNum)
         return;
 
     if (!fileName.isEmpty()) {
-        queueCmd(new GDBCommand(QCString().sprintf("tbreak %s:%d", fileName.latin1(), lineNum), NOTINFOCMD, 0));
-        queueCmd(new GDBCommand(QCString().sprintf("jump %s:%d", fileName.latin1(), lineNum), NOTINFOCMD, 0));
+        queueCmd(new GDBCommand(QCString().sprintf("tbreak %s:%d", fileName.latin1(), lineNum)));
+        queueCmd(new GDBCommand(QCString().sprintf("jump %s:%d", fileName.latin1(), lineNum)));
     }
 }
 
@@ -1223,7 +1225,7 @@ void GDBController::slotStepInto()
 
     removeStateReloadingCommands();
 
-    queueCmd(new GDBCommand("-exec-step", this));
+    queueCmd(new GDBCommand("-exec-step"));
 }
 
 // **************************************************************************
@@ -1235,7 +1237,7 @@ void GDBController::slotStepIntoIns()
 
     removeStateReloadingCommands();
 
-    queueCmd(new GDBCommand("-exec-step-instruction", this));
+    queueCmd(new GDBCommand("-exec-step-instruction"));
 }
 
 // **************************************************************************
@@ -1247,7 +1249,7 @@ void GDBController::slotStepOver()
 
     removeStateReloadingCommands();
 
-    queueCmd(new GDBCommand("-exec-next", this));
+    queueCmd(new GDBCommand("-exec-next"));
 }
 
 // **************************************************************************
@@ -1259,7 +1261,7 @@ void GDBController::slotStepOverIns()
 
     removeStateReloadingCommands();
 
-    queueCmd(new GDBCommand("-exec-next-instruction", this));
+    queueCmd(new GDBCommand("-exec-next-instruction"));
 }
 
 // **************************************************************************
@@ -1271,7 +1273,7 @@ void GDBController::slotStepOutOff()
 
     removeStateReloadingCommands();
 
-    queueCmd(new GDBCommand("-exec-finish", NOTINFOCMD, 0));
+    queueCmd(new GDBCommand("-exec-finish"));
 }
 
 // **************************************************************************
@@ -1284,42 +1286,6 @@ void GDBController::slotBreakInto()
 
 // **************************************************************************
 
-void GDBController::slotMemoryDump(
-    MemoryCallback* callback,
-    const QString &address, const QString &amount)
-{
-    if (stateIsOn(s_dbgBusy|s_dbgNotStarted|s_shuttingDown))
-        return;
-
-    QCString cmd = QCString().sprintf("x/%sb %s", 
-                                      amount.stripWhiteSpace().latin1(),
-                                      address.latin1());
-    currentMemoryCallback_ = callback;
-    queueCmd(new GDBCommand(cmd, INFOCMD, MEMDUMP));
-}
-
-// **************************************************************************
-
-void GDBController::slotRegisters()
-{
-    if (stateIsOn(s_dbgBusy|s_dbgNotStarted|s_shuttingDown))
-        return;
-
-    queueCmd(new GDBCommand("info all-registers", INFOCMD, REGISTERS));
-}
-
-// **************************************************************************
-
-void GDBController::slotLibraries()
-{
-    if (stateIsOn(s_dbgBusy|s_dbgNotStarted|s_shuttingDown))
-        return;
-
-    queueCmd(new GDBCommand("info sharedlibrary", INFOCMD, LIBRARIES));
-}
-
-// **************************************************************************
-
 void GDBController::selectFrame(int frameNo, int threadNo)
 {
     // FIXME: this either should be removed completely, or
@@ -1331,13 +1297,11 @@ void GDBController::selectFrame(int frameNo, int threadNo)
     {
         if (viewedThread_ != threadNo)
             queueCmd(new GDBCommand(
-                         QString("-thread-select %1").arg(threadNo).ascii(),
-                         INFOCMD));
+                         QString("-thread-select %1").arg(threadNo).ascii()));
     }
 
     queueCmd(new GDBCommand(
-                 QString("-stack-select-frame %1").arg(frameNo).ascii(),
-                 INFOCMD));
+                 QString("-stack-select-frame %1").arg(frameNo).ascii()));
 
     // Will emit the 'thread_or_frame_changed' event.
     queueCmd(new GDBCommand("-stack-info-frame",
@@ -1345,7 +1309,7 @@ void GDBController::selectFrame(int frameNo, int threadNo)
 
 
     // FIXME: the above commands might not be the first in queue, and
-    // previous commands might using values of 'viewedThread_' or 
+    // previous commands might using values of 'viewedThread_' or
     // 'currentFrame_'. Ideally, should change the values only after
     // response from gdb.
     viewedThread_ = threadNo;
@@ -1367,12 +1331,12 @@ void GDBController::defaultErrorHandler(const GDBMI::ResultRecord& result)
     }
 
     KMessageBox::error(
-        0, 
-        i18n("<b>Debugger error</b>" 
+        0,
+        i18n("<b>Debugger error</b>"
              "<p>Debugger reported the following error:"
              "<p><tt>") + result["msg"].literal(),
-        i18n("Debugger error"));                         
-    
+        i18n("Debugger error"));
+
     // Error most likely means that some change made in GUI
     // was not communicated to the gdb, so GUI is now not
     // in sync with gdb. Resync it.
@@ -1386,7 +1350,7 @@ void GDBController::defaultErrorHandler(const GDBMI::ResultRecord& result)
     // Also, don't reload state on errors appeared during state
     // reloading!
     if (stateReloadingCommands_.count(currentCmd_) == 0)
-        raiseEvent(program_state_changed);    
+        raiseEvent(program_state_changed);
 }
 
 void GDBController::processMICommandResponse(const GDBMI::ResultRecord& result)
@@ -1413,11 +1377,11 @@ void GDBController::processMICommandResponse(const GDBMI::ResultRecord& result)
             currentCmd_->invokeHandler(result);
             stateReloadInProgress_ = false;
         }
-    }    
+    }
     else if (result.reason == "error")
     {
         // Some commands want to handle errors themself.
-        if (currentCmd_->handlesError() &&
+        if (currentCmd_ && currentCmd_->handlesError() &&
             currentCmd_->invokeHandler(result))
         {
             // Done, nothing more needed
@@ -1452,7 +1416,7 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
     }
 
     bool ready_for_next_command = false;
-    
+
     int i;
     bool got_any_command = false;
     // For each gdb reply. In MI mode, each reply is one string.
@@ -1488,11 +1452,17 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
 
                 if (result.reason != "running")
                 {
-                    kdDebug(9012) << "Command execution time " 
+                    kdDebug(9012) << "Command execution time "
                                   << commandExecutionTime.elapsed() << " ms.\n";
                 }
 
-                if (!currentCmd_ || currentCmd_->typeMatch(USERCMD))
+                /* The currentCmd_ may be NULL here, because when detaching
+                   from debugger, we directly write "detach" to gdb and
+                   busy-wait for a reply.  Uisng the commands mechanism
+                   won't work there, because command result are
+                   communicated asynchronously.
+                   This is will be fixed in KDevelop4.  */
+                if (currentCmd_ && currentCmd_->isUserCommand())
                     emit gdbUserCommandStdout(reply);
                 else
                     emit gdbInternalCommandStdout(reply + "\n");
@@ -1500,7 +1470,7 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
                 if (result.reason == "stopped")
                 {
                     // Transfers ownership.
-                    // Needed so that in 
+                    // Needed so that in
                     //   handleMiFileListExecSourceFile(GDBMI::ResultRecord& r);
                     // we can use the last stop reason.
                     last_stop_result.reset(static_cast<GDBMI::ResultRecord*>(r.get()));
@@ -1526,7 +1496,7 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
                 if (ready_for_next_command)
                 {
                     // Need to do this before procesing response,
-                    // so that when processing response we don't 
+                    // so that when processing response we don't
                     // think that application is running.
                     setStateOff(s_appRunning);
                 }
@@ -1543,10 +1513,10 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
                 break;
             }
 
-            case GDBMI::Record::Stream: {            
+            case GDBMI::Record::Stream: {
 
                 GDBMI::StreamRecord& s = dynamic_cast<GDBMI::StreamRecord&>(*r);
-                if (!currentCmd_ || currentCmd_->typeMatch(USERCMD))
+                if (!currentCmd_ || currentCmd_->isUserCommand())
                     emit gdbUserCommandStdout(s.message.ascii());
                 else
                     emit gdbInternalCommandStdout(s.message.ascii());
@@ -1561,21 +1531,21 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
                 if (print_output.search(s.message) != -1)
                 {
                     kdDebug(9012) << "Found 'print' output: " << s.message << "\n";
-                    print_command_result = s.message.ascii(); 
+                    print_command_result = s.message.ascii();
                 }
 
                 break;
             }
-            
 
-            case GDBMI::Record::Prompt: 
+
+            case GDBMI::Record::Prompt:
                 break;
             }
         }
         catch(const std::exception& e)
         {
             KMessageBox::detailedSorry(
-                0, 
+                0,
                 i18n("<b>Internal debugger error</b>",
                      "<p>The debugger component encountered internal error while "
                      "processing reply from gdb. Please submit a bug report."),
@@ -1587,7 +1557,7 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
             ready_for_next_command = true;
         }
     }
-          
+
     // check the queue for any commands to send
     if (ready_for_next_command)
     {
@@ -1598,7 +1568,7 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
         kdDebug(9012) << "COMMANDS: " << cmdList_.count() << " in queue, "
                       << int(bool(currentCmd_)) << " executing\n";
 
-    commandDone(); 
+    commandDone();
 }
 
 void GDBController::commandDone()
@@ -1640,7 +1610,7 @@ void GDBController::removeStateReloadingCommands()
         GDBCommand* cmd = cmdList_.at(i);
         if (stateReloadingCommands_.count(cmd));
         {
-            kdDebug(9012) << "UNQUEUE: " << cmd->rawDbgCommand() << "\n";
+            kdDebug(9012) << "UNQUEUE: " << cmd->initialString() << "\n";
             delete cmdList_.take(i);
         }
     }
@@ -1650,7 +1620,7 @@ void GDBController::removeStateReloadingCommands()
         // This effectively prevents handler for this command
         // to be ever invoked.
         destroyCurrentCommand();
-    }    
+    }
 }
 
 void GDBController::raiseEvent(event_t e)
@@ -1702,7 +1672,7 @@ void GDBController::slotDbgProcessExited(KProcess* process)
     bool abnormal = !process->normalExit();
     delete dbgProcess_;
     dbgProcess_ = 0;
-    delete tty_;           
+    delete tty_;
     tty_ = 0;
 
     if (abnormal)
@@ -1721,11 +1691,11 @@ void GDBController::slotDbgProcessExited(KProcess* process)
 
 void GDBController::slotUserGDBCmd(const QString& cmd)
 {
-    queueCmd(new GDBCommand(cmd.latin1(), INFOCMD, USERCMD));
+    queueCmd(new UserCommand(cmd.latin1()));
 
     // User command can theoreticall modify absolutely everything,
-    // so need to force a reload. 
-    
+    // so need to force a reload.
+
     // We can do it right now, and don't wait for user command to finish
     // since commands used to reload all view will be executed after
     // user command anyway.
@@ -1738,7 +1708,7 @@ void GDBController::explainDebuggerStatus()
     QString information("%1 commands in queue\n"
                         "%2 commands being processed by gdb\n"
                         "Debugger state: %3\n");
-    information = 
+    information =
         information.arg(cmdList_.count()).arg(currentCmd_ ? 1 : 0)
         .arg(state_);
 
@@ -1750,28 +1720,28 @@ void GDBController::explainDebuggerStatus()
 
         extra = extra.arg(
             typeid(*currentCmd_).name()).arg(currentCmd_->cmdToSend()).
-            arg(currentCmd_->rawDbgCommand());
+            arg(currentCmd_->initialString());
         information += extra;
     }
 
     KMessageBox::information(0, information, "Debugger status");
 }
 
-bool GDBController::stateIsOn(int state) 
+bool GDBController::stateIsOn(int state)
 {
     return state_ & state;
 }
 
-void GDBController::setStateOn(int stateOn)    
+void GDBController::setStateOn(int stateOn)
 {
     debugStateChange(state_, state_ | stateOn);
-    state_ |= stateOn; 
+    state_ |= stateOn;
 }
 
-void GDBController::setStateOff(int stateOff)  
-{ 
+void GDBController::setStateOff(int stateOff)
+{
     debugStateChange(state_, state_ & ~stateOff);
-    state_ &= ~stateOff; 
+    state_ &= ~stateOff;
 }
 
 void GDBController::setState(int newState)
@@ -1828,9 +1798,18 @@ int GDBController::qtVersion( ) const
   return DomUtil::readIntEntry( dom, "/kdevcppsupport/qt/version", 3 );
 }
 
+void GDBController::demandAttention() const
+{
+    if ( QWidget * w = kapp->mainWidget() )
+    {
+        KWin::demandAttention( w->winId(), true );
+    }
+}
+
 }
 
 // **************************************************************************
 // **************************************************************************
 // **************************************************************************
+
 #include "gdbcontroller.moc"
