@@ -43,8 +43,6 @@ class DbgCommand;
 class GDBCommand;
 class VarItem;
 class STTY;
-class MemoryCallback;
-class ValueCallback;
 
 /**
  * A front end implementation to the gdb command line debugger
@@ -82,6 +80,10 @@ public:
     */
     void addCommand(GDBCommand* cmd);
 
+    /** Same as above, but internally constructs new GDBCommand
+       instance from the string. */
+    void addCommand(const QString& cmd);
+
     /** Adds command to the front of the commands queue. It will be executed
         next.
 
@@ -105,6 +107,12 @@ public:
     */
     void addCommandToFront(GDBCommand* cmd);
 
+    /* If current command queue has any command
+       for which isRun is true, inserts 'cmd'
+       before the first such command. Otherwise,
+       works the same as addCommand. */
+    void addCommandBeforeRun(GDBCommand* cmd);
+
     /** Selects the specified thread/frame. Immediately emits
         thread_or_frame_changed event.
     */
@@ -127,10 +135,20 @@ public:
 
     int qtVersion() const;
 
+    /**
+     * Call this when something very interesting happens that the user
+     * might be unaware of. It will make KDevelop's taskbar entry flash
+     * if the application doesn't already have focus.
+     * Typical use case: The debugger has stopped on a breakpoint.
+     */
+    void demandAttention() const;
+
     void pauseApp();
 
 protected:
-    void queueCmd(GDBCommand *cmd, bool executeNext=false);
+    enum queue_where { queue_at_end, queue_at_front, queue_before_run };
+
+    void queueCmd(GDBCommand *cmd, enum queue_where queue_where = queue_at_end);
 
 private:
     void parseLocals          (char type, char *buf);
@@ -221,11 +239,6 @@ public slots:
 
     void slotBreakInto();
 
-    void slotMemoryDump(MemoryCallback* callback,
-                        const QString &start, const QString &amount);
-    void slotRegisters();
-    void slotLibraries();
-
     void slotUserGDBCmd(const QString&);
 
     // Pops up a dialog box with some hopefully
@@ -277,7 +290,6 @@ private:
 
     QPtrList<GDBCommand> cmdList_;
     GDBCommand*       currentCmd_;
-    MemoryCallback*   currentMemoryCallback_;
 
     STTY*             tty_;
     QString           badCore_;
