@@ -3,8 +3,9 @@
 #include "$NEWFILENAMELC$.h"
 
 $NEWCLASS$::$NEWCLASS$(QWidget* parent, Qt::WFlags fl)
-: $QTBASECLASS$( parent, fl )
+: $QTBASECLASS$( parent, fl ), Ui::$BASECLASS$
 {
+	setupUi(this);
 }
 
 $NEWCLASS$::~$NEWCLASS$()
