@@ -61,15 +61,7 @@
 #include <ktexteditor/viewcursorinterface.h>
 #include <ktexteditor/clipboardinterface.h>
 
-#if defined(KDE_MAKE_VERSION)
-# if KDE_VERSION >= KDE_MAKE_VERSION(3,1,90)
-#  include <ktexteditor/texthintinterface.h>
-# else
-#  include <kde30x_texthintinterface.h>
-# endif
-#else
-#  include <kde30x_texthintinterface.h>
-#endif
+#include <ktexteditor/texthintinterface.h>
 
 #include <kdevcore.h>
 #include <kdevproject.h>
@@ -534,9 +526,15 @@ JavaSupportPart::parseProject( )
     QDir d( m_projectDirectory );
 
     QDataStream stream;
-    QMap< QString, QPair<uint, Q_LONG> > pcs;
+    QMap< QString, QPair<uint, uint> > pcs;
 
-    QFile f( project()->projectDirectory() + "/" + project()->projectName() + ".pcs" );
+    if( QFileInfo( project()->projectDirectory() + "/" + 
+			    project()->projectName().lower() + ".kdevelop.pcs" ).exists() )
+    {
+        d.rename(project()->projectName().lower() + ".kdevelop.pcs", 
+			project()->projectName() + ".kdevelop.pcs");
+    }
+    QFile f(project()->projectDirectory() + "/" + project()->projectName() + ".kdevelop.pcs");
     if( f.open(IO_ReadOnly) ){
 	stream.setDevice( &f );
 
@@ -551,7 +549,7 @@ JavaSupportPart::parseProject( )
 	    for( int i=0; i<numFiles; ++i ){
 		QString fn;
 		uint ts;
-		Q_LONG offset;
+		uint offset;
 
 		stream >> fn >> ts >> offset;
 		pcs[ fn ] = qMakePair( ts, offset );
@@ -737,11 +735,7 @@ void JavaSupportPart::setupCatalog( )
 
     if( pcsList.size() && pcsVersion() < KDEV_DB_VERSION ){
         QStringList l = pcsList + pcsIdxList;
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,4,0)
         int rtn = KMessageBox::questionYesNoList( 0, i18n("Persistant class store will be disabled: you have a wrong version of pcs installed.\nRemove old pcs files?"), l, i18n("Java Support"), KStdGuiItem::remove(), i18n("Keep Them") );
-#else
-        int rtn = KMessageBox::questionYesNoList( 0, i18n("Persistant class store will be disabled: you have a wrong version of pcs installed.\nRemove old pcs files?"), l, i18n("Java Support"), KGuiItem( i18n( "&Remove" ), "editdelete", i18n( "Remove item(s)" )), i18n("Keep Them") );
-#endif
         if( rtn == KMessageBox::Yes ){
             QStringList::Iterator it = l.begin();
             while( it != l.end() ){
@@ -876,12 +870,13 @@ void JavaSupportPart::saveProjectSourceInfo( )
     if( !project() || fileList.isEmpty() )
 	return;
 
-    QFile f( project()->projectDirectory() + "/" + project()->projectName() + ".pcs" );
+    QFile f( project()->projectDirectory() + "/" + 
+		    project()->projectName() + ".kdevelop.pcs" );
     if( !f.open( IO_WriteOnly ) )
 	return;
 
     QDataStream stream( &f );
-    QMap<QString, Q_ULONG> offsets;
+    QMap<QString, uint> offsets;
 
     QString pcs( "PCS" );
     stream << pcs << KDEV_PCS_VERSION;
@@ -895,7 +890,7 @@ void JavaSupportPart::saveProjectSourceInfo( )
   stream << dom->name() << toTime_t(m_timestamp[ dom->name() ]);
 #endif
 	offsets.insert( dom->name(), stream.device()->at() );
-	stream << (Q_ULONG)0; // dummy offset
+	stream << (uint)0; // dummy offset
     }
 
     for( FileList::ConstIterator it=fileList.begin(); it!=fileList.end(); ++it ){
