@@ -747,7 +747,7 @@ void RDBController::slotStart(const QString& ruby_interpreter, const QString& ch
 		*dbgProcess_ << run_arguments;
 	}
 
-    emit rdbStdout(QString( ruby_interpreter + character_coding
+    emit rdbStdout(QString( ruby_interpreter + " " + character_coding
 							+ " -C " + QString(QFile::encodeName( run_directory ))
 							+ " -r " + debuggee_path + " " 
 							+ application + " " + run_arguments ).latin1() );
@@ -1195,7 +1195,7 @@ void RDBController::slotAcceptConnection(int masterSocket)
 	
 	socket_ = accept(masterSocket, &sockaddr, &fromlen);
 	if (fcntl(socket_, F_SETFL, O_NONBLOCK) == -1) {
-    	kdDebug(9012) << "RDBController::slotAcceptConnection can't set nonblocking socket" << errno << endl;
+    	kdDebug(9012) << "RDBController::slotAcceptConnection can't set nonblocking socket " << errno << endl;
 	}
 	
 	socketNotifier_ = new QSocketNotifier(socket_, QSocketNotifier::Read, 0);
