@@ -3,9 +3,9 @@
 
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
- * $Id: ASTRefCount.hpp,v 1.3 2003/07/01 17:17:07 raggi Exp $
+ * $Id: ASTRefCount.hpp 626096 2007-01-22 06:35:06Z okellogg $
  */
 
 # include <antlr/config.hpp>
@@ -83,18 +83,12 @@ public:
 		}
 		return *this;
 	}
-	
-	ASTRefCount<AST> toRefAST() { return ASTRefCount<AST>( static_cast<AST*>(ref->ptr) ); }
 
 	operator T* ()  const { return ref ? static_cast<T*>(ref->ptr) : 0; }
 	T* operator->() const { return ref ? static_cast<T*>(ref->ptr) : 0; }
 	T* get()        const { return ref ? static_cast<T*>(ref->ptr) : 0; }
 };
 
-#if defined(_MSC_VER) && !defined(__ICL) // Microsoft Visual C++
-extern template class ANTLR_API ASTRefCount<AST>;
-#endif
-
 typedef ASTRefCount<AST> RefAST;
 
 #ifdef ANTLR_CXX_SUPPORTS_NAMESPACE
