@@ -1,7 +1,8 @@
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
+ * $Id: ASTFactory.cpp 626096 2007-01-22 06:35:06Z okellogg $
  */
 
 #include "antlr/CommonAST.hpp"
@@ -11,6 +12,7 @@
 #include "antlr/ANTLRUtil.hpp"
 
 #include <iostream>
+#include <istream>
 
 using namespace std;
 
@@ -35,7 +37,7 @@ namespace antlr {
 
 /// Initialize factory
 ASTFactory::ASTFactory()
-: default_factory_descriptor(ANTLR_USE_NAMESPACE(std)make_pair(static_cast<const char*>("CommonAST"),&CommonAST::factory))
+: default_factory_descriptor(ANTLR_USE_NAMESPACE(std)make_pair(CommonAST::TYPE_NAME,&CommonAST::factory))
 {
 	nodeFactories.resize( Token::MIN_USER_TYPE, &default_factory_descriptor );
 }
