@@ -46,10 +46,6 @@ using namespace filetreeview;
 ///////////////////////////////////////////////////////////////////////////////
 
 #include <kdeversion.h>
-#if (KDE_VERSION_MINOR==0) && (KDE_VERSION_MAJOR==3)
-#include <kdevkurl.h>
-#define KURL KdevKURL
-#endif
 
 ///////////////////////////////////////////////////////////////////////////////
 // class FileTreeWidget
@@ -136,8 +132,8 @@ void FileTreeWidget::openDirectory( const QString& dirName )
 bool FileTreeWidget::shouldBeShown( KFileTreeViewItem* item )
 {
     FileTreeViewItem * i = static_cast<FileTreeViewItem *>( item );
-    return( (m_impl->showNonProjectFiles() || i->isDir() || i->isProjectFile() )
-             && !matchesHidePattern( i->url().fileName() ) );
+    return ( i->isDir() || ( (m_impl->showNonProjectFiles() || i->isProjectFile() )
+             && !matchesHidePattern( i->url().fileName() ) ) ) ;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
