@@ -162,19 +162,24 @@ GrepDialog::GrepDialog( GrepViewPart * part, QWidget *parent, const char *name )
     dir_combo->setMinimumWidth(dir_combo->fontMetrics().maxWidth()*25);
     dir_layout->addWidget( url_requester, 10 );
 
-	synch_button = new QPushButton(".", this );
-	QToolTip::add( synch_button, i18n("Set directory to that of the current file") );
-	dir_layout->addWidget( synch_button );
+    synch_button = new KPushButton( this );
+    QIconSet set = SmallIconSet( "dirsynch" );
+    QPixmap pix = set.pixmap( QIconSet::Small, QIconSet::Normal );
+    synch_button->setFixedSize( pix.width()+8, pix.height()+8 );
+    synch_button->setIconSet( set );
+    synch_button->setAccel( QKeySequence( "Alt+y") );
+    QToolTip::add( synch_button, i18n("Set directory to that of the current file (Alt+Y)") );
+    dir_layout->addWidget( synch_button );
 
     QBoxLayout *dir_checks_layout = new QHBoxLayout(5);
     layout->addLayout(dir_checks_layout, 5, 1);
 
-    regexp_box = new QCheckBox(i18n("Regular &Expression"), this);
-    regexp_box->setChecked(true);
+    regexp_box = new QCheckBox(i18n("&Regular Expression"), this);
+    regexp_box->setChecked(config->readBoolEntry("regexp", false ));
     dir_checks_layout->addSpacing(10);
     dir_checks_layout->addWidget(regexp_box);
 
-    recursive_box = new QCheckBox(i18n("&Recursive"), this);
+    recursive_box = new QCheckBox(i18n("Rec&ursive"), this);
     recursive_box->setChecked(config->readBoolEntry("recursive", true));
     dir_checks_layout->addSpacing(10);
     dir_checks_layout->addWidget(recursive_box);
@@ -196,7 +201,7 @@ GrepDialog::GrepDialog( GrepViewPart * part, QWidget *parent, const char *name )
 
     QBoxLayout *button_layout = new QHBoxLayout(4);
     layout->addLayout(button_layout, 6, 1);
-    search_button = new KPushButton(KGuiItem(i18n("&Search"),"grep"), this);
+    search_button = new KPushButton(KGuiItem(i18n("Sea&rch"),"grep"), this);
     search_button->setDefault(true);
     KPushButton *done_button = new KPushButton(KStdGuiItem::cancel(), this);
     button_layout->addStretch();
@@ -268,6 +273,7 @@ GrepDialog::~GrepDialog()
     // memorize the last patterns and paths
     config->writeEntry("LastSearchItems", qCombo2StringList(pattern_combo));
     config->writePathEntry("LastSearchPaths", qCombo2StringList(dir_combo));
+	config->writeEntry("regexp", regexp_box->isChecked());
 	config->writeEntry("recursive", recursive_box->isChecked());
 	config->writeEntry("case_sens", case_sens_box->isChecked());
 	config->writeEntry("new_view", keep_output_box->isChecked());
@@ -334,11 +340,18 @@ void GrepDialog::show()
     // not beautiful, but works with all window
     // managers and Qt versions
     if (isVisible())
-        QDialog::hide();
+        hide();
+//         QDialog::hide();
     QDialog::show();
     pattern_combo->setFocus();
 }
 
+void GrepDialog::hide()
+{
+	pattern_combo->setFocus();
+	QDialog::hide();
+}
+
 void GrepDialog::slotSynchDirectory( )
 {
 	KParts::ReadOnlyPart * part = dynamic_cast<KParts::ReadOnlyPart*>( m_part->partController()->activePart() );
