@@ -58,7 +58,9 @@ GrepListBoxItem::GrepListBoxItem(const QString &fileName, const QString &lineNum
 		: ProcessListBoxItem( QString::null, Normal),
 		fileName(fileName), lineNumber(lineNumber), text(text.stripWhiteSpace()),
 		show(showFilename)
-{}
+{
+	this->text.replace( QChar('\t'), QString("  ") );
+}
 
 
 bool GrepListBoxItem::isCustomItem()
@@ -107,7 +109,7 @@ void GrepListBoxItem::paint(QPainter *p)
 	}
 	else
 	{
-		p->setPen(dim);
+		p->setPen(base);
 		QFont font1(p->font());
 		QFont font2(font1);
 		font2.setBold(true);
@@ -116,7 +118,7 @@ void GrepListBoxItem::paint(QPainter *p)
 		p->setFont(font1);
 		x += fm.width(stx);
 
-		p->setPen(Qt::blue);
+		p->setPen(result);
 		p->drawText(x, y, text);
 	}
 }
