@@ -21,7 +21,11 @@
 #ifndef QUICKOPENDIALOG_H
 #define QUICKOPENDIALOG_H
 
+#include <qstringlist.h>
+#include <qtimer.h>
+
 #include <codemodel.h>
+
 #include "quickopenbase.h"
 
 class QuickOpenPart;
@@ -41,10 +45,13 @@ public:
   
 public slots:
   virtual void slotTextChanged(const QString&);
+  virtual void slotTextChangedDelayed();
 
 protected:
-	KCompletion* m_completion;
-	QuickOpenPart* m_part;
+    QStringList wildCardCompletion( const QString & text );
+    QStringList m_items;
+    QuickOpenPart* m_part;
+    QTimer m_typeTimeout;
 
 };
 
