@@ -145,7 +145,8 @@ void ReplaceWidget::showDialog()
 void ReplaceWidget::find()
 {
     _listview->clear();
-    m_part->mainWindow()->raiseView(this);
+    m_part->mainWindow()->raiseView( this );
+    m_part->mainWindow()->setViewAvailable( this, true );
 
     _listview->setReplacementData( m_dialog->expressionPattern(), m_dialog->replacementString() );
 
@@ -157,6 +158,7 @@ void ReplaceWidget::find()
     else
     {
         clear();
+        m_part->mainWindow()->setViewAvailable( this, false );
     }
 }
 
@@ -164,6 +166,7 @@ void ReplaceWidget::replace()
 {
     makeReplacements();
     clear();
+    m_part->mainWindow()->setViewAvailable( this, false );
 }
 
 void ReplaceWidget::clear()
@@ -172,6 +175,8 @@ void ReplaceWidget::clear()
 
     _cancel->setEnabled( false );
     _replace->setEnabled( false );
+
+    m_part->mainWindow()->setViewAvailable( this, false );
 }
 
 void ReplaceWidget::editDocument( QString const & file, int line )
@@ -296,18 +301,7 @@ bool ReplaceWidget::makeReplacements()
 
                     _listview->makeReplacementsForFile( istream, ostream, fileitem );
 
-                    // pre 3.1.3 katepart clears undo history on setText()
-                    #if defined(KDE_MAKE_VERSION)
-                    # if KDE_VERSION > KDE_MAKE_VERSION(3,1,2)
                     ei->setText( obuffer );
-                    # else
-                    ei->removeText( 0, 0, ei->numLines()-1, UINT_MAX );
-                    ei->insertText( 0, 0, obuffer );
-                    # endif
-                    #else
-                    ei->removeText( 0, 0, ei->numLines()-1, UINT_MAX );
-                    ei->insertText( 0, 0, obuffer );
-                    #endif
                 }
             }
             else
