@@ -17,7 +17,6 @@
 #include "partcontroller.h"
 #include "core.h"
 #include "projectmanager.h"
-#include "newmainwindow.h"
 
 #include "kdevideextension.h"
 
@@ -33,7 +32,7 @@ int main(int argc, char *argv[])
   static const char description[] = I18N_NOOP("The KDevelop Integrated Development Environment");
   KAboutData aboutData("kdevelop", I18N_NOOP("KDevelop"),
                        VERSION, description, KAboutData::License_GPL,
-                       I18N_NOOP("(c) 1999-2006, The KDevelop developers"), "", "http://www.kdevelop.org");
+                       I18N_NOOP("(c) 1999-2007, The KDevelop developers"), "", "http://www.kdevelop.org");
   aboutData.addAuthor("Alexander Dymo", I18N_NOOP("Release coordinator, Overall improvements, Pascal support, C++ support, New File and Documentation parts"), "adymo@kdevelop.org");
   aboutData.addAuthor("Amilcar do Carmo Lucas", I18N_NOOP("Release coordinator, API documentation, Doxygen and autoproject patches"), "amilcar@ida.ing.tu-bs.de");
   aboutData.addAuthor("David Nolden", I18N_NOOP("Advanced C++ code completion, C++ support, overall improvements"), "david.nolden.kdevelop@art-master.de");
@@ -112,11 +111,6 @@ int main(int argc, char *argv[])
   Core::getInstance()->doEmitCoreInitialized();
 
   if (splash) splash->message( i18n( "Starting GUI" ) );
-//BEGIN a workaround on kmdi bug - we do not allow mainwindow to be shown until now
-  NewMainWindow *mw = dynamic_cast<NewMainWindow*>(TopLevel::getInstance()->main());
-  if (mw)
-      mw->enableShow();
-//END workaround
   TopLevel::getInstance()->main()->show();
 
   if (splash) delete splash;
