@@ -27,6 +27,7 @@
 
 #include <kdebug.h>
 #include <kiconloader.h>
+#include <kxmlguiclient.h>
 #include <kaction.h>
 #include <kpopupmenu.h>
 #include <kinputdialog.h>
@@ -69,6 +70,9 @@ Button::Button(ButtonBar *parent, const QString text, const QIconSet &icon,
 Button::~Button()
 {
 //     m_buttonBar->removeButton(this);
+    KConfig *config = kapp->config();
+    config->setGroup("UI");
+
     QRegExp r("^&([0-9])\\s.*");
     QRegExp r2("^&[0-9]\\s");
     if (r.search(m_realText) > -1)
@@ -76,10 +80,12 @@ Button::~Button()
         QString text = m_realText;
         if (text.contains(r2))
             text.remove(r2);
-        KConfig *config = kapp->config();
-        config->setGroup("UI");
         config->writeEntry(QString("button_%1").arg(text), r.cap(1));
     }
+    else
+    {
+        config->writeEntry(QString("button_%1").arg(m_realText), "");
+    }
 }
 
 void Button::setDescription(const QString &description)
@@ -322,6 +328,7 @@ void Button::setRealText(const QString &text)
 {
     m_realText = text;
     setText(text);
+    updateSize();
 }
 
 void Button::clearAccel()
