@@ -26,6 +26,7 @@
 #include <kfiledialog.h>
 #include <kmainwindow.h>
 #include <kaction.h>
+#include <kmessagebox.h>
 #include <kstatusbar.h>
 #include <khtml_part.h>
 #include <kpopupmenu.h>
@@ -65,13 +66,14 @@
 #include "multibuffer.h"
 #include "partcontroller.h"
 
+
 class QDomDocument;
 
 PartController *PartController::s_instance = 0;
 
 using namespace MainWindowUtils;
 
-struct HistoryEntry 
+struct HistoryEntry
 {
     KURL url;
     QString context;
@@ -157,10 +159,6 @@ void PartController::setupActions()
   m_closeOtherWindowsAction->setWhatsThis(i18n("<b>Close all others</b><p>Close all opened files except current."));
   m_closeOtherWindowsAction->setEnabled(false);
 
-  m_switchToAction = new KAction(i18n("Switch To..."), KShortcut("CTRL+/"), this, SLOT(slotSwitchTo()), ac, "file_switchto");
-  m_switchToAction->setToolTip(i18n("Switch to"));
-  m_switchToAction->setWhatsThis(i18n("<b>Switch to</b><p>Prompts to enter the name of previously opened file to switch to."));
-
   new KActionSeparator(ac, "dummy_separator");
 
   m_backAction = new KToolBarPopupAction(i18n("Back"), "back", 0, this, SLOT(slotBack()), ac, "history_back");
@@ -287,17 +285,19 @@ void PartController::editDocumentInternal( const KURL & inputUrl, int lineNum,
 		if ( API::getInstance()->project() )
 		{
 			if (url.isRelativeURL(url.url())) {
-				KURL relURL(API::getInstance()->project()->projectDirectory(), url.url());
+				KURL relURL(API::getInstance()->project()->projectDirectory());
+				relURL.addPath( url.url() );
 
 				kdDebug() << k_funcinfo << "Looking for file in project dir: " << API::getInstance()->project()->projectDirectory() << " url " << url.url() << " transformed to " << relURL.url() << ": " << done << endl;
-				if (relURL.isValid() && KIO::NetAccess::exists(url, false, 0)) {
+				if (relURL.isValid() && KIO::NetAccess::exists(relURL, false, 0)) {
 					url = relURL;
 					done = true;
 				}
 				else {
-					KURL relURL(API::getInstance()->project()->buildDirectory(), url.url());
+					KURL relURL(API::getInstance()->project()->buildDirectory());
+					relURL.addPath( url.url() );
 					kdDebug() << k_funcinfo << "Looking for file in build dir: " << API::getInstance()->project()->buildDirectory() << " url " << url.url() << " transformed to " << relURL.url() << ": " << done << endl;
-					if (relURL.isValid() && KIO::NetAccess::exists(url, false, 0)) {
+					if (relURL.isValid() && KIO::NetAccess::exists(relURL, false, 0)) {
 						url = relURL;
 						done = true;
 					}
@@ -316,7 +316,7 @@ void PartController::editDocumentInternal( const KURL & inputUrl, int lineNum,
 			}
 		}
 
-		if ( !done && ( !url.isValid() || !KIO::NetAccess::exists(url, false, 0) ))
+ 		if ( !done && ( !url.isValid() || !KIO::NetAccess::exists(url, false, 0) ))
 		{
 			// Not found - prompt the user to find it?
 			kdDebug(9000) << "cannot find URL: " << url.url() << endl;
@@ -388,59 +388,55 @@ void PartController::editDocumentInternal( const KURL & inputUrl, int lineNum,
 	// we don't trust KDE with designer files, let's handle it ourselves
 	if ( !m_openNextAsText && MimeType->is( "application/x-designer" ) )
 	{
+		QString DesignerSetting = config->readEntry( "DesignerSetting", "ExternalDesigner" );
+		QString designerExec = "designer";
+		QStringList designerPluginPaths;
 		QDomDocument* dom = API::getInstance()->projectDom();
 		if ( dom != 0 )
 		{
-
-			// Short explanation for the following: 
 			// The global option specifies a fallback if the project
 			// has no setting or no project is open. However for Qt4
 			// projects we want to use ExternalDesigner in any case.
-			QString DefaultDesignerSetting = config->readEntry( "DesignerSetting", "ExternalDesigner" );
-
 			if ( DomUtil::readIntEntry( *dom, "/kdevcppsupport/qt/version", 3 ) == 4 )
-				DefaultDesignerSetting = "ExternalDesigner";
+			{
+				designerPluginPaths = DomUtil::readListEntry(*dom, "/kdevcppsupport/qt/designerpluginpaths", "path" );
+				DesignerSetting = "ExternalDesigner";
+			}
 
-			QString DesignerSetting = DomUtil::readEntry(*dom, "/kdevcppsupport/qt/designerintegration", DefaultDesignerSetting );
-
-			if ( DesignerSetting == "EmbeddedKDevDesigner" )
-			{
-				if ( KParts::ReadOnlyPart *designerPart = qtDesignerPart() )
-				{
-					addHistoryEntry();
-					activatePart(designerPart);
-					designerPart->openURL(url);
-					return;
-				}
-				else if ( KParts::Factory * KDevDesignerFactory = static_cast<KParts::Factory*>( KLibLoader::self()->factory( QFile::encodeName( "libkdevdesignerpart" ) ) ) )
-				{
-					KParts::ReadWritePart * kdevpart = static_cast<KParts::ReadWritePart*>( KDevDesignerFactory->createPart( TopLevel::getInstance()->main(), 0, 0, 0, "KParts::ReadWritePart"  ) );
-					kdevpart->openURL( url );
-					addHistoryEntry();
-					integratePart( kdevpart, url );
-					m_openRecentAction->addURL( url );
-					m_openRecentAction->saveEntries( kapp->config(), "RecentFiles" );
-					return;
-				}
-			}
-	
-			QString designerDesktopName;
-	
-			if ( DesignerSetting == "ExternalKDevDesigner" )
-			{
-				designerDesktopName = "kdevdesigner";
-			}
-			else
-			{
-				QString QtDir = DomUtil::readEntry(*dom, "/kdevcppsupport/qt/root");
-				if ( QtDir != QString::null )
-					designerDesktopName = QtDir+"/bin/";
-				designerDesktopName += "designer";
-			}
-	
-			KRun::run( designerDesktopName, url );
-			return;
+			DesignerSetting = DomUtil::readEntry(*dom, "/kdevcppsupport/qt/designerintegration", DesignerSetting  );
+			designerExec = DomUtil::readEntry(*dom, "/kdevcppsupport/qt/designer", designerExec );
 		}
+		if ( DesignerSetting == "ExternalKDevDesigner" )
+		{
+			designerExec = "kdevdesigner";
+		}
+		else if ( DesignerSetting == "EmbeddedKDevDesigner" )
+		{
+			if ( KParts::ReadOnlyPart *designerPart = qtDesignerPart() )
+			{
+				addHistoryEntry();
+				activatePart(designerPart);
+				designerPart->openURL(url);
+				return;
+			}
+			else if ( KParts::Factory * KDevDesignerFactory = static_cast<KParts::Factory*>( KLibLoader::self()->factory( QFile::encodeName( "libkdevdesignerpart" ) ) ) )
+			{
+				KParts::ReadWritePart * kdevpart = static_cast<KParts::ReadWritePart*>( KDevDesignerFactory->createPart( TopLevel::getInstance()->main(), 0, 0, 0, "KParts::ReadWritePart"  ) );
+				kdevpart->openURL( url );
+				addHistoryEntry();
+				integratePart( kdevpart, url );
+				m_openRecentAction->addURL( url );
+				m_openRecentAction->saveEntries( kapp->config(), "RecentFiles" );
+				return;
+			}
+		}
+
+		if( designerPluginPaths.isEmpty() )
+			KRun::runCommand( designerExec+" "+url.pathOrURL() );
+		else
+			KRun::runCommand( "QT_PLUGIN_PATH=\""+designerPluginPaths.join(":")+"\" "+designerExec+" "+url.pathOrURL() );
+
+		return;
 	}
 
 	config->setGroup("General");
@@ -864,7 +860,7 @@ KParts::ReadOnlyPart *PartController::partForURL(const KURL &url)
 	for ( ; it.current(); ++it)
 	{
 		KParts::ReadOnlyPart *ro_part = dynamic_cast<KParts::ReadOnlyPart*>(it.current());
-		if (ro_part && url == ro_part->url())
+		if (ro_part && url.path() == ro_part->url().path())
 			return ro_part;
 	}
 	return 0;
@@ -1275,6 +1271,14 @@ void PartController::slotOpenFile()
 		DefaultEncoding = DomUtil::readEntry( *projectDom, "/general/defaultencoding", QString::null );
 	}
 
+	if ( DefaultEncoding.isEmpty() )
+	{
+		// have a peek at katepart's settings:
+		KConfig * config = kapp->config();
+		config->setGroup("Kate Document Defaults");
+		DefaultEncoding = config->readEntry("Encoding", QString::null );
+	}
+
 	KEncodingFileDialog::Result result = KEncodingFileDialog::getOpenURLsAndEncoding( DefaultEncoding, QString::null,
 		QString::null, TopLevel::getInstance()->main(), QString::null );
 
@@ -1309,44 +1313,11 @@ void PartController::slotActivePartChanged( KParts::Part *part )
         KXMLGUIClient* client = dynamic_cast<KXMLGUIClient*>(part->widget());
         if (client) Core::setupShourtcutTips(client);
     }
-    
+
     updateMenuItems();
     QTimer::singleShot( 100, this, SLOT(slotWaitForFactoryHack()) );
 }
 
-void PartController::slotSwitchTo()
-{
-    QMap<QString,KParts::ReadOnlyPart*> parts_map;
-    QStringList part_list;
-    QPtrList<KParts::Part> pl = *parts();
-    KParts::Part *part;
-    for(part=pl.first();part;part=pl.next()) {
-        kdDebug(9000) << "Part..." << endl;
-	if (part->inherits("KParts::ReadOnlyPart")) {
-	    KParts::ReadOnlyPart *ro_part = static_cast<KParts::ReadOnlyPart*>(part);
-            QString name = ro_part->url().fileName();
-	    part_list.append(name);
-            parts_map[name] = ro_part;
-            kdDebug(9000) << "Found part for URL " << ro_part->url().prettyURL() << endl;
-	}
-    }
-
-    KDialogBase dialog(KDialogBase::Plain, i18n("Switch To"), KDialogBase::Ok|KDialogBase::Cancel,
-		       KDialogBase::Ok, 0, "Switch to", true);
-    QGridLayout *grid = new QGridLayout( dialog.plainPage(), 2, 1, 10, 10);
-    KLineEdit *editbox = new KLineEdit(dialog.plainPage());
-    grid->addWidget(new QLabel( i18n("Switch to buffer:"), dialog.plainPage() ), 0, 0);
-    grid->addWidget(editbox, 1, 0);
-    editbox->completionObject()->setItems( part_list );
-    editbox->setFocus();
-    int result = dialog.exec();
-    if (result==KDialogBase::KDialogBase::Accepted) {
-        if (parts_map.contains(editbox->text())) {
-            activatePart(parts_map[editbox->text()]);
-        }
-    }
-}
-
 void PartController::showPart( KParts::Part* part, const QString& name, const QString& shortDescription )
 {
   if (!part->widget()) {
@@ -1387,10 +1358,10 @@ void PartController::slotDocumentDirty( Kate::Document * d, bool isModified, uns
 		++it;
 	}
 
-	// this is a bit strange, but in order to avoid weird crashes 
-	// down in KDirWatcher, we want to step off the call chain before 
-	// opening any messageboxes 
-	if ( doc ) 
+	// this is a bit strange, but in order to avoid weird crashes
+	// down in KDirWatcher, we want to step off the call chain before
+	// opening any messageboxes
+	if ( doc )
 	{
 		ModificationData * p = new ModificationData;
 		p->doc = doc;
@@ -1406,7 +1377,7 @@ void PartController::slotDocumentDirtyStepTwo( void * payload )
 
 	ModificationData * p = reinterpret_cast<ModificationData*>( payload );
 	KTextEditor::Document * doc = p->doc;
-	
+
 	// let's make sure the document is still loaded
 	bool haveDocument = false;
 	if( const QPtrList<KParts::Part> * partlist = parts() )
@@ -1423,7 +1394,7 @@ void PartController::slotDocumentDirtyStepTwo( void * payload )
 		}
 	}
 	if ( !haveDocument ) return;
-	
+
 	bool isModified = p->isModified;
 	unsigned char reason = p->reason;
 	delete p;
@@ -1720,9 +1691,9 @@ void PartController::jumpTo( const HistoryEntry & entry )
 
 
 PartController::HistoryEntry PartController::createHistoryEntry( KParts::ReadOnlyPart * ro_part ) {
-    if( ro_part == 0 ) 
+    if( ro_part == 0 )
         ro_part = dynamic_cast<KParts::ReadOnlyPart*>( activePart() );
-    
+
     if ( !ro_part ) return HistoryEntry();
     KTextEditor::ViewCursorInterface * cursorIface = dynamic_cast<KTextEditor::ViewCursorInterface*>( ro_part->widget() );
     if ( !cursorIface ) return HistoryEntry();
@@ -1825,6 +1796,8 @@ KTextEditor::Editor *PartController::openTextDocument( bool activate )
 
         EditorProxy::getInstance()->setLineNumber(editorpart, 0, 0);
     }
+
+    return editorpart;
 }
 
 void PartController::textChanged()
