@@ -42,6 +42,7 @@
 #include <profileengine.h>
 #include <designer.h>
 #include <kdevproject.h>
+#include <urlutil.h>
 
 #include "api.h"
 #include "core.h"
@@ -54,6 +55,7 @@
 #include "toplevel.h"
 #include "projectmanager.h"
 #include "editorproxy.h"
+#include "multibuffer.h"
 
 SimpleMainWindow::SimpleMainWindow(QWidget* parent, const char *name)
     :DMainWindow(parent, name)
@@ -164,7 +166,19 @@ void SimpleMainWindow::contextMenu(QPopupMenu *popupMenu, const Context *context
     {
         if (PartController::getInstance()->openURLs().count() > 0)
         {
-            m_splitURLs = static_cast<const FileContext*>(context)->urls();
+            KURL::List urls = static_cast<const FileContext*>(context)->urls();
+            KURL::List::ConstIterator it = urls.begin();
+            while ( it != urls.end() )
+            {
+                if ( !URLUtil::isDirectory( *it ) )
+                {
+                    m_splitURLs.append( *it );
+                }
+                ++it;
+            }
+
+            if ( m_splitURLs.isEmpty() ) return;
+
             bool isOpen = true;
             for (KURL::List::const_iterator it = m_splitURLs.begin(); it != m_splitURLs.end(); ++it)
             {
@@ -257,11 +271,6 @@ void SimpleMainWindow::rememberToolViewPosition( const QString & name, DDockWind
     KConfig * config = kapp->config();
     config->setGroup( "DToolDockPosition" );
 
-    if ( name == "unknown" )
-    {
-        kdDebug() << name << endl;
-    }
-
     QString position = "unknown";
 
     switch( pos )
@@ -362,6 +371,11 @@ void SimpleMainWindow::saveSettings( )
     QMap<QWidget*, DDockWindow::Position>::iterator it = m_docks.begin();
     while ( it != m_docks.end() )
     {
+        if ( !strcmp(it.key()->name(), "unnamed") )
+        {
+            kdError() << "Toolviews must have a name : " << it.key() << endl;
+        }
+
         rememberToolViewPosition( it.key()->name(), it.data() );
         ++it;
     }
@@ -407,21 +421,27 @@ void SimpleMainWindow::createActions()
 
     m_splitHor = new KAction(i18n("Split &Horizontal"), CTRL+SHIFT+Key_T,
         this, SLOT(slotSplitHorizontalBase()), actionCollection(), "split_h");
+    m_splitHor->setIcon("view_top_bottom");
 
     m_splitVer = new KAction(i18n("Split &Vertical"), CTRL+SHIFT+Key_L,
         this, SLOT(slotSplitVerticalBase()), actionCollection(), "split_v");
+    m_splitVer->setIcon("view_left_right");
 
     m_splitHor1 = new KAction(i18n("Split &Horizontal"), 0,
         this, SLOT(slotSplitHorizontal()), actionCollection(), "split_h1");
+    m_splitHor1->setIcon("view_top_bottom");
 
     m_splitVer1 = new KAction(i18n("Split &Vertical"), 0,
         this, SLOT(slotSplitVertical()), actionCollection(), "split_v1");
+    m_splitVer1->setIcon("view_left_right");
 
     m_splitHor2 = new KAction(i18n("Split &Horizontal and Open"), 0,
         this, SLOT(slotSplitHorizontal()), actionCollection(), "split_h2");
+    m_splitHor2->setIcon("view_top_bottom");
 
     m_splitVer2 = new KAction(i18n("Split &Vertical and Open"), 0,
         this, SLOT(slotSplitVertical()), actionCollection(), "split_v2");
+    m_splitVer2->setIcon("view_left_right");
 
     m_raiseLeftDock = new KAction(i18n("Switch Left Dock"), CTRL+SHIFT+ALT+Key_L,
         this, SLOT(raiseLeftDock()), actionCollection(), "switch_left_dock");
@@ -551,6 +571,7 @@ void SimpleMainWindow::documentChangedState(const KURL &url, DocumentState state
                 break;
         }
     }
+    setCaption(url.url());
 }
 
 void SimpleMainWindow::closeTab()
@@ -847,7 +868,16 @@ void SimpleMainWindow::closeTab(QWidget *w)
         QWidget *widget = EditorProxy::getInstance()->topWidgetForPart(part);
         if (widget && widget == w)
         {
-            PartController::getInstance()->closePart(part);
+            // weirdness beyond weirdness.. sometimes the active view is an embedded splitter with two files
+            // so we check if the widget is a multibuffer, in which case we let it decide what part to close
+            if (MultiBuffer * mb = dynamic_cast<MultiBuffer*>( widget ) )
+            {
+                PartController::getInstance()->closePart( mb->activeBuffer() );
+            }
+            else
+            {
+                PartController::getInstance()->closePart(part);
+            }
             return;
         }
         ++it;
@@ -943,6 +973,16 @@ void SimpleMainWindow::switchToNextTabWidget()
 
 void SimpleMainWindow::setCaption(const QString &caption)
 {
+    kdDebug(9000) << k_funcinfo << endl;
+
+    bool modified = false;
+    if ( !caption.isEmpty() )
+    {
+        KURL url( caption );
+        DocumentState const state = PartController::getInstance()->documentState( url );
+        modified = ( state == Modified || state == DirtyAndModified );
+    }
+
     KDevProject *project = API::getInstance()->project();
     if (project)
     {
@@ -953,12 +993,12 @@ void SimpleMainWindow::setCaption(const QString &caption)
             projectname.truncate(projectname.length() - suffix.length());
 
         if (!caption.isEmpty())
-            DMainWindow::setCaption(projectname + " - " + caption);
+            DMainWindow::setCaption(projectname + " - " + caption, modified);
         else
-            DMainWindow::setCaption(projectname);
+            DMainWindow::setCaption(projectname, modified);
     }
     else
-        DMainWindow::setCaption(caption);
+        DMainWindow::setCaption(caption, modified);
 }
 
 void SimpleMainWindow::projectClosed()
