@@ -363,15 +363,9 @@ bool CvsServicePartImpl::checkout()
 
     if ( dlg.exec() == QDialog::Accepted )
     {
-#if KDE_IS_VERSION(3,2,90)
         DCOPRef job = m_cvsService->checkout( dlg.workDir(), dlg.serverPath(),
             dlg.module(), dlg.tag(), dlg.pruneDirs(), "", false
         );
-#else
-        DCOPRef job = m_cvsService->checkout( dlg.workDir(), dlg.serverPath(),
-            dlg.module(), dlg.tag(), dlg.pruneDirs()
-        );
-#endif
         if (!m_cvsService->ok()) {
             KMessageBox::sorry( mainWindow()->main(), i18n( "Unable to checkout" ) );
         } else {
@@ -842,11 +836,7 @@ void CvsServicePartImpl::addFilesToProject( const QStringList &filesToAdd )
     int s = KMessageBox::questionYesNo( 0,
         i18n("Do you want to be added to CVS repository too?"),
         i18n("CVS - New Files Added to Project"),
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
         KStdGuiItem::add(),
-#else
-        i18n( "Add Files"),
-#endif
         i18n("Do Not Add"),
         i18n("askWhenAddingNewFiles") );
     if (s == KMessageBox::Yes)
@@ -869,19 +859,12 @@ void CvsServicePartImpl::removedFilesFromProject(const QStringList &filesToRemov
     if (filesInCVS.isEmpty())
         return;
 
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
     int s = KMessageBox::warningContinueCancel( 0,
         i18n("Do you want them to be removed from CVS repository too?\nWarning: They will be removed from disk too."),
         i18n("CVS - Files Removed From Project"),
         KStdGuiItem::del(),
         i18n("askWhenRemovingFiles") );
-#else
-    int s = KMessageBox::warningContinueCancel( 0,
-        i18n("Do you want them to be removed from CVS repository too?\nWarning: They will be removed from disk too."),
-        i18n("CVS - Files Removed From Project"),
-        KGuiItem( i18n( "&Delete" ), "editdelete", i18n( "Delete item(s)" )),
-        i18n("askWhenRemovingFiles") );
-#endif
+
     if (s == KMessageBox::Continue)
     {
         kdDebug( 9006 ) << "Removing these files: " << filesInCVS.join( ", " ) << endl;
