@@ -28,11 +28,7 @@
 #include <kmainwindow.h>
 #include <qregexp.h>
 
-#if KDE_VERSION <= KDE_MAKE_VERSION(3,3,90)
-#include "../compat/netaccess/netaccess.h"
-#else
 #include <kio/netaccess.h>
-#endif
 
 SVNFileInfoProvider::SVNFileInfoProvider(subversionPart *parent, const char *name)
     : KDevVCSFileInfoProvider( parent, "svnfileinfoprovider" ),
@@ -68,11 +64,7 @@ const VCSFileInfoMap *SVNFileInfoProvider::status( const QString &dirPath ) {
 
 
 		QMap<QString,QString> ma;
-#if KDE_VERSION <= KDE_MAKE_VERSION(3,3,90)
-		KIO_COMPAT::NetAccess::synchronousRun(job2, m_part->mainWindow()->main(), 0, 0, &ma );
-#else
 		KIO::NetAccess::synchronousRun(job2, m_part->mainWindow()->main(), 0, 0, &ma );
-#endif
 
 		QValueList<QString> keys = ma.keys();
 		qHeapSort( keys );
